var searchData=
[
  ['package',['PACKAGE',['../plplot__config_8h.html#aca8570fb706c81df371b7f9bc454ae03',1,'plplot_config.h']]],
  ['pallen',['PALLEN',['../plctrl_8c.html#af13363833e712d00d7dd399495eaa20a',1,'plctrl.c']]],
  ['pdf_5fbadnbits',['PDF_BADNBITS',['../pdf_8h.html#ab14a7e0b1ca0f81e0c1d57af33ed1d1e',1,'pdf.h']]],
  ['pdf_5fbadun',['PDF_BADUN',['../pdf_8h.html#a7e84a04c1db1e8921a42d12a7980d584',1,'pdf.h']]],
  ['pdf_5ferror',['PDF_ERROR',['../pdf_8h.html#a3b4fd55183dee0537b35844ec952240b',1,'pdf.h']]],
  ['pdf_5ffaopen',['PDF_FAOPEN',['../pdf_8h.html#ab3c83276e43943a1d8848441e8e33128',1,'pdf.h']]],
  ['pdf_5ffnopen',['PDF_FNOPEN',['../pdf_8h.html#a1a931846f7f0ffeafae7520afbb7859d',1,'pdf.h']]],
  ['pdf_5fnotpdf',['PDF_NOTPDF',['../pdf_8h.html#acf58c71c93e941bde1b612d6ddb05100',1,'pdf.h']]],
  ['pdf_5frderr',['PDF_RDERR',['../pdf_8h.html#a652e46c949ce7336ed4b04f0236410a0',1,'pdf.h']]],
  ['pdf_5fwrerr',['PDF_WRERR',['../pdf_8h.html#ab62e91f4cec5fcbdf9bb597edc777a60',1,'pdf.h']]],
  ['pen',['PEN',['../plstripc_8c.html#aa858f2fbc6c6e9ddf6eabb0f22d1d136',1,'plstripc.c']]],
  ['pi',['PI',['../plplotP_8h.html#a598a3330b3c21701223ee0ca14316eca',1,'plplotP.h']]],
  ['pixel_5fres_5fx_5fold',['PIXEL_RES_X_OLD',['../metadefs_8h.html#a96730d05ad2a07a4b19fe154f24137f2',1,'metadefs.h']]],
  ['pixel_5fres_5fy_5fold',['PIXEL_RES_Y_OLD',['../metadefs_8h.html#aa982f9019bc39bba612f10b4363a7814',1,'metadefs.h']]],
  ['pixels_5fx',['PIXELS_X',['../plplotP_8h.html#a66d6dc4355bd8c6a9a28b79c59162928',1,'plplotP.h']]],
  ['pixels_5fy',['PIXELS_Y',['../plplotP_8h.html#af9852bb02ab4e984728d84e4e464d10d',1,'plplotP.h']]],
  ['pl_5fbin_5fcentred',['PL_BIN_CENTRED',['../plplot_8h.html#af3461c53e333e2bbe43b64bf21057aa1',1,'plplot.h']]],
  ['pl_5fbin_5fdefault',['PL_BIN_DEFAULT',['../plplot_8h.html#aee12fc4bc22f8e999ed745d1df31c795',1,'plplot.h']]],
  ['pl_5fbin_5fnoempty',['PL_BIN_NOEMPTY',['../plplot_8h.html#ac84d30741184027686cbac2707d21123',1,'plplot.h']]],
  ['pl_5fbin_5fnoexpand',['PL_BIN_NOEXPAND',['../plplot_8h.html#a297710e408c30539e95fd20aa87f9997',1,'plplot.h']]],
  ['pl_5fcolorbar_5fbackground',['PL_COLORBAR_BACKGROUND',['../plplot_8h.html#a1886a7e2aee9c95828fca4eda4261ffe',1,'plplot.h']]],
  ['pl_5fcolorbar_5fbounding_5fbox',['PL_COLORBAR_BOUNDING_BOX',['../plplot_8h.html#ad4a664cdb2585e4c37fe1a3b07bafd6c',1,'plplot.h']]],
  ['pl_5fcolorbar_5fcap_5fhigh',['PL_COLORBAR_CAP_HIGH',['../plplot_8h.html#a42c124d5c2e9932e3d27d1dd347d1b17',1,'plplot.h']]],
  ['pl_5fcolorbar_5fcap_5flow',['PL_COLORBAR_CAP_LOW',['../plplot_8h.html#ac2879db42d0c9d963cb2d3a74e953ec4',1,'plplot.h']]],
  ['pl_5fcolorbar_5fcap_5fnone',['PL_COLORBAR_CAP_NONE',['../plplot_8h.html#a2afd94d27753eaa659949bad09b9faea',1,'plplot.h']]],
  ['pl_5fcolorbar_5fgradient',['PL_COLORBAR_GRADIENT',['../plplot_8h.html#aa339ae32d9e3d5cdbd953040d2bfe46a',1,'plplot.h']]],
  ['pl_5fcolorbar_5fimage',['PL_COLORBAR_IMAGE',['../plplot_8h.html#a54d6629ba95fb6413fbf6451f16d6e65',1,'plplot.h']]],
  ['pl_5fcolorbar_5flabel_5fbottom',['PL_COLORBAR_LABEL_BOTTOM',['../plplot_8h.html#aabc96a420c830731f6ece5694a9adc60',1,'plplot.h']]],
  ['pl_5fcolorbar_5flabel_5fleft',['PL_COLORBAR_LABEL_LEFT',['../plplot_8h.html#ac81ae9a4c7016376c8904cbdc6f29aee',1,'plplot.h']]],
  ['pl_5fcolorbar_5flabel_5fright',['PL_COLORBAR_LABEL_RIGHT',['../plplot_8h.html#a83fb83c49b854017aeb18c2160911a92',1,'plplot.h']]],
  ['pl_5fcolorbar_5flabel_5ftop',['PL_COLORBAR_LABEL_TOP',['../plplot_8h.html#a38466c6fea905d6221e6a338f71d9b5b',1,'plplot.h']]],
  ['pl_5fcolorbar_5forient_5fbottom',['PL_COLORBAR_ORIENT_BOTTOM',['../plplot_8h.html#a3515daea0a292f5471fa2ad275990b09',1,'plplot.h']]],
  ['pl_5fcolorbar_5forient_5fleft',['PL_COLORBAR_ORIENT_LEFT',['../plplot_8h.html#ae9a9558d97dfdb6d9fd92fcc70e28678',1,'plplot.h']]],
  ['pl_5fcolorbar_5forient_5fright',['PL_COLORBAR_ORIENT_RIGHT',['../plplot_8h.html#ac6cb8a5f5563286a76b84f3c8ddeab34',1,'plplot.h']]],
  ['pl_5fcolorbar_5forient_5ftop',['PL_COLORBAR_ORIENT_TOP',['../plplot_8h.html#a3df04608a202ec76624bbc0036cb1b6c',1,'plplot.h']]],
  ['pl_5fcolorbar_5fshade',['PL_COLORBAR_SHADE',['../plplot_8h.html#aea4a4532c00c254591c5a58ca92b5875',1,'plplot.h']]],
  ['pl_5fcolorbar_5fshade_5flabel',['PL_COLORBAR_SHADE_LABEL',['../plplot_8h.html#a58a4cf16afb401d8c65f944770c53d49',1,'plplot.h']]],
  ['pl_5fdefault_5fcmap0_5ffile',['PL_DEFAULT_CMAP0_FILE',['../plplot__config_8h.html#afbf5142dfff94e591a7b4f22cd3c163f',1,'plplot_config.h']]],
  ['pl_5fdefault_5fcmap1_5ffile',['PL_DEFAULT_CMAP1_FILE',['../plplot__config_8h.html#ab035fe71ecb650b38509704a6084231c',1,'plplot_config.h']]],
  ['pl_5fdouble',['PL_DOUBLE',['../plConfig_8h.html#a9713670c0bc31fbd2270fbf9d577949d',1,'plConfig.h']]],
  ['pl_5fdrawmode_5fdefault',['PL_DRAWMODE_DEFAULT',['../plplot_8h.html#ac5eeff3ef245c5b23310ba17946a284a',1,'plplot.h']]],
  ['pl_5fdrawmode_5freplace',['PL_DRAWMODE_REPLACE',['../plplot_8h.html#a4ae91e69b166f8e0b208bf5ddc1173f8',1,'plplot.h']]],
  ['pl_5fdrawmode_5funknown',['PL_DRAWMODE_UNKNOWN',['../plplot_8h.html#a88ed02445de7f47970e9b5d21c4719d5',1,'plplot.h']]],
  ['pl_5fdrawmode_5fxor',['PL_DRAWMODE_XOR',['../plplot_8h.html#a8fe9ae3ea64f7c6b720e378ea759dc8f',1,'plplot.h']]],
  ['pl_5ffci_5fbold',['PL_FCI_BOLD',['../plplot_8h.html#abb99575234e2ce19c89f844684491983',1,'plplot.h']]],
  ['pl_5ffci_5ffamily',['PL_FCI_FAMILY',['../plplot_8h.html#acb6b245aaed9f9661123fee7abeb6a9f',1,'plplot.h']]],
  ['pl_5ffci_5fhexdigit_5fmask',['PL_FCI_HEXDIGIT_MASK',['../plplot_8h.html#a2a22a6ef2d6ca75b687d542a71547ddf',1,'plplot.h']]],
  ['pl_5ffci_5fhexpower_5fimpossible',['PL_FCI_HEXPOWER_IMPOSSIBLE',['../plplot_8h.html#a23dd416cb2d438844f986aa1d2e3c187',1,'plplot.h']]],
  ['pl_5ffci_5fhexpower_5fmask',['PL_FCI_HEXPOWER_MASK',['../plplot_8h.html#ab912c7efb044fda08307c1d9626dfa90',1,'plplot.h']]],
  ['pl_5ffci_5fimpossible',['PL_FCI_IMPOSSIBLE',['../plplot_8h.html#a788353da464c0933acae712eed0eada8',1,'plplot.h']]],
  ['pl_5ffci_5fitalic',['PL_FCI_ITALIC',['../plplot_8h.html#af2422f894b3c18285a52d0e0ae5ed5f0',1,'plplot.h']]],
  ['pl_5ffci_5fmark',['PL_FCI_MARK',['../plplot_8h.html#af74899890d487af9aacd1b1ab62cffb8',1,'plplot.h']]],
  ['pl_5ffci_5fmedium',['PL_FCI_MEDIUM',['../plplot_8h.html#a17be14f72a7e52c1e81571643da91a1a',1,'plplot.h']]],
  ['pl_5ffci_5fmono',['PL_FCI_MONO',['../plplot_8h.html#a47ef514965ea1c4045e43abb85d82909',1,'plplot.h']]],
  ['pl_5ffci_5foblique',['PL_FCI_OBLIQUE',['../plplot_8h.html#a7b7df74d045a46cb0f96f3524d3396d8',1,'plplot.h']]],
  ['pl_5ffci_5fsans',['PL_FCI_SANS',['../plplot_8h.html#ae0dac4c7803a98b70eda4e0dfbe2c41f',1,'plplot.h']]],
  ['pl_5ffci_5fscript',['PL_FCI_SCRIPT',['../plplot_8h.html#a24b37d7e840722ba23305ff91b0232a7',1,'plplot.h']]],
  ['pl_5ffci_5fserif',['PL_FCI_SERIF',['../plplot_8h.html#ac50e4663acf81c75285da6c9d1d7df1e',1,'plplot.h']]],
  ['pl_5ffci_5fstyle',['PL_FCI_STYLE',['../plplot_8h.html#ac55bfe409e42314412f2a130595610c7',1,'plplot.h']]],
  ['pl_5ffci_5fsymbol',['PL_FCI_SYMBOL',['../plplot_8h.html#af4c902b64e13f552fcc2793172b0e4c7',1,'plplot.h']]],
  ['pl_5ffci_5fupright',['PL_FCI_UPRIGHT',['../plplot_8h.html#a9f9d1c25dbb88256a528b6e307ac2e13',1,'plplot.h']]],
  ['pl_5ffci_5fweight',['PL_FCI_WEIGHT',['../plplot_8h.html#a56a2e7aff93cc40a833762f13d95e5a1',1,'plplot.h']]],
  ['pl_5ffgetpos',['pl_fgetpos',['../plplotP_8h.html#a1746fea2cbee4c8b3bea3cb9e5368d13',1,'plplotP.h']]],
  ['pl_5ffilesize_5fkb',['PL_FILESIZE_KB',['../plplotP_8h.html#a981a886d6a99eebc2bd4aaf96b744a4a',1,'plplotP.h']]],
  ['pl_5ffreetype_5ffont_5fdir',['PL_FREETYPE_FONT_DIR',['../plplot__config_8h.html#ab2540d6f1ba31485291420467f4beae3',1,'plplot_config.h']]],
  ['pl_5ffreetype_5fmono',['PL_FREETYPE_MONO',['../plplot__config_8h.html#ac2d1b0959e8c70d23f2cb38f622c7967',1,'plplot_config.h']]],
  ['pl_5ffreetype_5fmono_5fbold',['PL_FREETYPE_MONO_BOLD',['../plplot__config_8h.html#ae6f14d0d0a2829f401f5923b719c1598',1,'plplot_config.h']]],
  ['pl_5ffreetype_5fmono_5fbold_5fitalic',['PL_FREETYPE_MONO_BOLD_ITALIC',['../plplot__config_8h.html#a69d69134da7e2277acee3802f1be0c48',1,'plplot_config.h']]],
  ['pl_5ffreetype_5fmono_5fbold_5foblique',['PL_FREETYPE_MONO_BOLD_OBLIQUE',['../plplot__config_8h.html#aae69ce4bae8d60783c9223489cea52ae',1,'plplot_config.h']]],
  ['pl_5ffreetype_5fmono_5fitalic',['PL_FREETYPE_MONO_ITALIC',['../plplot__config_8h.html#a7259e6e960c82291dbad9a186ee3e5fb',1,'plplot_config.h']]],
  ['pl_5ffreetype_5fmono_5foblique',['PL_FREETYPE_MONO_OBLIQUE',['../plplot__config_8h.html#a41d50a7440ef6191abfa93744c8c0505',1,'plplot_config.h']]],
  ['pl_5ffreetype_5fsans',['PL_FREETYPE_SANS',['../plplot__config_8h.html#a0e38c92490f7ae6b0bab8dc7dbff728c',1,'plplot_config.h']]],
  ['pl_5ffreetype_5fsans_5fbold',['PL_FREETYPE_SANS_BOLD',['../plplot__config_8h.html#a8b4fc7d0e70703d85e0a766372581085',1,'plplot_config.h']]],
  ['pl_5ffreetype_5fsans_5fbold_5fitalic',['PL_FREETYPE_SANS_BOLD_ITALIC',['../plplot__config_8h.html#a5ae7495f34e9a6f0ea8cb950a517167e',1,'plplot_config.h']]],
  ['pl_5ffreetype_5fsans_5fbold_5foblique',['PL_FREETYPE_SANS_BOLD_OBLIQUE',['../plplot__config_8h.html#adb0f879380ac73196cddc6c4422352b1',1,'plplot_config.h']]],
  ['pl_5ffreetype_5fsans_5fitalic',['PL_FREETYPE_SANS_ITALIC',['../plplot__config_8h.html#a7293685c220ace6fc1a0bc82c84efb20',1,'plplot_config.h']]],
  ['pl_5ffreetype_5fsans_5foblique',['PL_FREETYPE_SANS_OBLIQUE',['../plplot__config_8h.html#a94c7dad552bb1ae36ff739dbd2c65c95',1,'plplot_config.h']]],
  ['pl_5ffreetype_5fscript',['PL_FREETYPE_SCRIPT',['../plplot__config_8h.html#a54b62dc23f98a8a3973789db5b743ab1',1,'plplot_config.h']]],
  ['pl_5ffreetype_5fscript_5fbold',['PL_FREETYPE_SCRIPT_BOLD',['../plplot__config_8h.html#a607dec6fc122f3f31ebe640b635d66dd',1,'plplot_config.h']]],
  ['pl_5ffreetype_5fscript_5fbold_5fitalic',['PL_FREETYPE_SCRIPT_BOLD_ITALIC',['../plplot__config_8h.html#aee8c80609c47005f96ae7d6a013843e2',1,'plplot_config.h']]],
  ['pl_5ffreetype_5fscript_5fbold_5foblique',['PL_FREETYPE_SCRIPT_BOLD_OBLIQUE',['../plplot__config_8h.html#aa73bee2e8863d7113de55e1ec8c545c8',1,'plplot_config.h']]],
  ['pl_5ffreetype_5fscript_5fitalic',['PL_FREETYPE_SCRIPT_ITALIC',['../plplot__config_8h.html#af8b0451abf58899cee4ea7b2bdff9297',1,'plplot_config.h']]],
  ['pl_5ffreetype_5fscript_5foblique',['PL_FREETYPE_SCRIPT_OBLIQUE',['../plplot__config_8h.html#a71a05a036c72a9148570be2dd7f5a3d3',1,'plplot_config.h']]],
  ['pl_5ffreetype_5fserif',['PL_FREETYPE_SERIF',['../plplot__config_8h.html#a0971290e99518f771fbc3c574641fef5',1,'plplot_config.h']]],
  ['pl_5ffreetype_5fserif_5fbold',['PL_FREETYPE_SERIF_BOLD',['../plplot__config_8h.html#aa77d28457fc3eb513fa0251bff236e7e',1,'plplot_config.h']]],
  ['pl_5ffreetype_5fserif_5fbold_5fitalic',['PL_FREETYPE_SERIF_BOLD_ITALIC',['../plplot__config_8h.html#ac6119ffebbc1ff3bed2fcf8c554df0b3',1,'plplot_config.h']]],
  ['pl_5ffreetype_5fserif_5fbold_5foblique',['PL_FREETYPE_SERIF_BOLD_OBLIQUE',['../plplot__config_8h.html#a4bd2c81e3767ea8caa210b7fd8aa8176',1,'plplot_config.h']]],
  ['pl_5ffreetype_5fserif_5fitalic',['PL_FREETYPE_SERIF_ITALIC',['../plplot__config_8h.html#a73ecaac219bd25c768c5f25cc9eeda24',1,'plplot_config.h']]],
  ['pl_5ffreetype_5fserif_5foblique',['PL_FREETYPE_SERIF_OBLIQUE',['../plplot__config_8h.html#a940d4a9766dcc9db348408445ee78d37',1,'plplot_config.h']]],
  ['pl_5ffreetype_5fsymbol',['PL_FREETYPE_SYMBOL',['../plplot__config_8h.html#ad4b3f77ccc980997ca738b0f9bc65a7f',1,'plplot_config.h']]],
  ['pl_5ffreetype_5fsymbol_5fbold',['PL_FREETYPE_SYMBOL_BOLD',['../plplot__config_8h.html#a52cbb5f9a2950b73590f526a4518d79b',1,'plplot_config.h']]],
  ['pl_5ffreetype_5fsymbol_5fbold_5fitalic',['PL_FREETYPE_SYMBOL_BOLD_ITALIC',['../plplot__config_8h.html#a0b43348948d0c1aed82f4be4ecbfcd03',1,'plplot_config.h']]],
  ['pl_5ffreetype_5fsymbol_5fbold_5foblique',['PL_FREETYPE_SYMBOL_BOLD_OBLIQUE',['../plplot__config_8h.html#af151184f8e96a99a7b33580505489200',1,'plplot_config.h']]],
  ['pl_5ffreetype_5fsymbol_5fitalic',['PL_FREETYPE_SYMBOL_ITALIC',['../plplot__config_8h.html#a1e743ba611f6b914991836536f532d53',1,'plplot_config.h']]],
  ['pl_5ffreetype_5fsymbol_5foblique',['PL_FREETYPE_SYMBOL_OBLIQUE',['../plplot__config_8h.html#a2e669a9e7a515854f4bb5bf24399e65f',1,'plplot_config.h']]],
  ['pl_5ffsetpos',['pl_fsetpos',['../plplotP_8h.html#a3420ee76baf4c39a9ffc040436fb45ad',1,'plplotP.h']]],
  ['pl_5fhave_5fcxx_5fstdint_5fh',['PL_HAVE_CXX_STDINT_H',['../plConfig_8h.html#ad4577754d54d8803d7b848f3b97cce63',1,'plConfig.h']]],
  ['pl_5fhave_5ffreetype',['PL_HAVE_FREETYPE',['../plplot__config_8h.html#a2f0ea431d3aa63fabfeb8f8c573a4222',1,'plplot_config.h']]],
  ['pl_5fhave_5fisfinite',['PL_HAVE_ISFINITE',['../plConfig_8h.html#ac2144d0cf3d949bb139a1159630bda54',1,'plConfig.h']]],
  ['pl_5fhave_5fisinf',['PL_HAVE_ISINF',['../plConfig_8h.html#a0a67b3df44a1488dec26d58b8bc50cee',1,'plConfig.h']]],
  ['pl_5fhave_5fisnan',['PL_HAVE_ISNAN',['../plConfig_8h.html#abeb307a7aa9027f7ce76b80d148a8f00',1,'plConfig.h']]],
  ['pl_5fhave_5fmkdtemp',['PL_HAVE_MKDTEMP',['../plplot__config_8h.html#afd4f50e96094fe0721cc0e6177df3c30',1,'plplot_config.h']]],
  ['pl_5fhave_5fmkfifo',['PL_HAVE_MKFIFO',['../plplot__config_8h.html#a0e9e0a8f9c9e57c118f5edc197c71b10',1,'plplot_config.h']]],
  ['pl_5fhave_5fmkstemp',['PL_HAVE_MKSTEMP',['../plplot__config_8h.html#a8c4d708aaed70db6830193ec98d27251',1,'plplot_config.h']]],
  ['pl_5fhave_5fnanosleep',['PL_HAVE_NANOSLEEP',['../plConfig_8h.html#a408953c65769be70e1022f7ad8c16128',1,'plConfig.h']]],
  ['pl_5fhave_5fpthread',['PL_HAVE_PTHREAD',['../plplot__config_8h.html#a271e95b80b144ea65d0df904f524eac7',1,'plplot_config.h']]],
  ['pl_5fhave_5fqhull',['PL_HAVE_QHULL',['../plplot__config_8h.html#a861cbeebd75b16deb31deff55741b6db',1,'plplot_config.h']]],
  ['pl_5fhave_5fsnprintf',['PL_HAVE_SNPRINTF',['../plConfig_8h.html#a5da0fe984cf25f9f440551028c50d3fe',1,'plConfig.h']]],
  ['pl_5fhave_5fstdint_5fh',['PL_HAVE_STDINT_H',['../plConfig_8h.html#ac35e251c237d15aefebc5fbb8565c7e3',1,'plConfig.h']]],
  ['pl_5fhave_5funistd_5fh',['PL_HAVE_UNISTD_H',['../plConfig_8h.html#ae1a91ba4cd7939fc4eb1cce011935366',1,'plConfig.h']]],
  ['pl_5fhave_5funlink',['PL_HAVE_UNLINK',['../plplot__config_8h.html#ab9bdb332f0b29622b75399c64440a564',1,'plplot_config.h']]],
  ['pl_5fhist_5fdefault',['PL_HIST_DEFAULT',['../plplot_8h.html#a9936c75a739fccdea85dca8085e5ff5c',1,'plplot.h']]],
  ['pl_5fhist_5fignore_5foutliers',['PL_HIST_IGNORE_OUTLIERS',['../plplot_8h.html#a2932c488ba81c8a43e0d1df8b0eae90e',1,'plplot.h']]],
  ['pl_5fhist_5fnoempty',['PL_HIST_NOEMPTY',['../plplot_8h.html#ad90d49c58811c225f9b40fe16b2c5269',1,'plplot.h']]],
  ['pl_5fhist_5fnoexpand',['PL_HIST_NOEXPAND',['../plplot_8h.html#ad045227a60fd1b7a6ba7484cbb9e9abf',1,'plplot.h']]],
  ['pl_5fhist_5fnoscaling',['PL_HIST_NOSCALING',['../plplot_8h.html#a114d7b8dffa03fd0dcdf52c336ff0241',1,'plplot.h']]],
  ['pl_5flegend_5fbackground',['PL_LEGEND_BACKGROUND',['../plplot_8h.html#a4b6b34d5a9d146919741267b91f8cf78',1,'plplot.h']]],
  ['pl_5flegend_5fbounding_5fbox',['PL_LEGEND_BOUNDING_BOX',['../plplot_8h.html#a7de3e124cb2c9d5aa7c9dc85efc70b72',1,'plplot.h']]],
  ['pl_5flegend_5fcolor_5fbox',['PL_LEGEND_COLOR_BOX',['../plplot_8h.html#a55f9fd02e3c80518f175dbd9b2c135bb',1,'plplot.h']]],
  ['pl_5flegend_5fline',['PL_LEGEND_LINE',['../plplot_8h.html#a70f997ff03bb62308ec6e6b82783d6ee',1,'plplot.h']]],
  ['pl_5flegend_5fnone',['PL_LEGEND_NONE',['../plplot_8h.html#a39430311ce223e88826f0c92864eeba3',1,'plplot.h']]],
  ['pl_5flegend_5frow_5fmajor',['PL_LEGEND_ROW_MAJOR',['../plplot_8h.html#a67acdb622747723dd63d61c8db77ec3f',1,'plplot.h']]],
  ['pl_5flegend_5fsymbol',['PL_LEGEND_SYMBOL',['../plplot_8h.html#af9035c908614e1db71828eb2de742597',1,'plplot.h']]],
  ['pl_5flegend_5ftext_5fleft',['PL_LEGEND_TEXT_LEFT',['../plplot_8h.html#ae8e673b57f1894dce563b5e3680f04d9',1,'plplot.h']]],
  ['pl_5flibrary',['PL_LIBRARY',['../tclAPI_8c.html#a2173a4ba9260869ae2c7473986d38d64',1,'tclAPI.c']]],
  ['pl_5fmask_5falt',['PL_MASK_ALT',['../plplot_8h.html#aa1eb47846f1cc3d98bc83d94cad2eb7c',1,'plplot.h']]],
  ['pl_5fmask_5faltgr',['PL_MASK_ALTGR',['../plplot_8h.html#acb2a51b6a28457d628c8c578ce05172d',1,'plplot.h']]],
  ['pl_5fmask_5fbutton1',['PL_MASK_BUTTON1',['../plplot_8h.html#a878d1870831513e95e4ae7f384cd4518',1,'plplot.h']]],
  ['pl_5fmask_5fbutton2',['PL_MASK_BUTTON2',['../plplot_8h.html#a0393ee301b2a7cfd750e8ec98446cbd8',1,'plplot.h']]],
  ['pl_5fmask_5fbutton3',['PL_MASK_BUTTON3',['../plplot_8h.html#ad1b4ee99616d467a0dc88faab30b5a9d',1,'plplot.h']]],
  ['pl_5fmask_5fbutton4',['PL_MASK_BUTTON4',['../plplot_8h.html#a8c6c90f372ce2e839bea9238d9381a6f',1,'plplot.h']]],
  ['pl_5fmask_5fbutton5',['PL_MASK_BUTTON5',['../plplot_8h.html#a1a098f5c7cbb862e3654afa6a97fc18b',1,'plplot.h']]],
  ['pl_5fmask_5fcaps',['PL_MASK_CAPS',['../plplot_8h.html#ac671965b731d43a6e8c4724f457a2521',1,'plplot.h']]],
  ['pl_5fmask_5fcontrol',['PL_MASK_CONTROL',['../plplot_8h.html#af9fc96a84fc9dee9edf56ed7e0d39390',1,'plplot.h']]],
  ['pl_5fmask_5fnum',['PL_MASK_NUM',['../plplot_8h.html#abae1bea515c5890690d8044ee9078b9c',1,'plplot.h']]],
  ['pl_5fmask_5fscroll',['PL_MASK_SCROLL',['../plplot_8h.html#a68518829448f461ef0b35a9be67a1567',1,'plplot.h']]],
  ['pl_5fmask_5fshift',['PL_MASK_SHIFT',['../plplot_8h.html#a514e51ab93bdea1c653fac78e59dda74',1,'plplot.h']]],
  ['pl_5fmask_5fwin',['PL_MASK_WIN',['../plplot_8h.html#a86730139aea11188477badb9d38d66b5',1,'plplot.h']]],
  ['pl_5fmax_5fcmap1cp',['PL_MAX_CMAP1CP',['../plstrm_8h.html#a25705184ffd1889685a32533fff307ea',1,'plstrm.h']]],
  ['pl_5fmax_5fopt_5ftables',['PL_MAX_OPT_TABLES',['../plargs_8c.html#adbc9642ac7a5151627a82da4cd124164',1,'plargs.c']]],
  ['pl_5fmaxkey',['PL_MAXKEY',['../plplot_8h.html#a44c035ac35674a4596e8e8ab9f01a556',1,'plplot.h']]],
  ['pl_5fmaxntmpdir_5flist',['PL_MAXNTMPDIR_LIST',['../plstdio_8c.html#a3f0272325b6d59ae0c676a703bb9a32f',1,'plstdio.c']]],
  ['pl_5fmaxpoly',['PL_MAXPOLY',['../plplotP_8h.html#a3ae78f9d70f3b5ee8e7fb790665f7f75',1,'plplotP.h']]],
  ['pl_5fmaxwindows',['PL_MAXWINDOWS',['../plplot_8h.html#ad4c0f054dbc15c9e5478c857912c35f8',1,'plplot.h']]],
  ['pl_5fnbcc',['PL_NBCC',['../plfill_8c.html#a7c56cc66ad4dff14f3ef34d6b600f4db',1,'plfill.c']]],
  ['pl_5fnotset',['PL_NOTSET',['../plplot_8h.html#a33abbe5268cf992ac1a9ed78c169d630',1,'plplot.h']]],
  ['pl_5fnstreams',['PL_NSTREAMS',['../plplotP_8h.html#ac7e5f6c5f87077c74bed1f3bcb54715d',1,'plplotP.h']]],
  ['pl_5fopt_5farg',['PL_OPT_ARG',['../plplot_8h.html#a7e09f1097e789e32c464ef427864b381',1,'plplot.h']]],
  ['pl_5fopt_5fbool',['PL_OPT_BOOL',['../plplot_8h.html#a949faa90745b619d61e7802ded01a8dd',1,'plplot.h']]],
  ['pl_5fopt_5fdisabled',['PL_OPT_DISABLED',['../plplot_8h.html#abc3c243c26445135d14eb219881e0966',1,'plplot.h']]],
  ['pl_5fopt_5fenabled',['PL_OPT_ENABLED',['../plplot_8h.html#a47bbd4447a07ca7ae2d1dbeb2dbc3a00',1,'plplot.h']]],
  ['pl_5fopt_5ffloat',['PL_OPT_FLOAT',['../plplot_8h.html#aeee44ed62e55d68e88d898c153043725',1,'plplot.h']]],
  ['pl_5fopt_5ffunc',['PL_OPT_FUNC',['../plplot_8h.html#a568b36886dddaa10bdc8f850279fc778',1,'plplot.h']]],
  ['pl_5fopt_5fint',['PL_OPT_INT',['../plplot_8h.html#a8ee2e2be02655057ab68049f9b7c8e55',1,'plplot.h']]],
  ['pl_5fopt_5finvisible',['PL_OPT_INVISIBLE',['../plplot_8h.html#a9fed284e2dad916ce20aa512912e66ad',1,'plplot.h']]],
  ['pl_5fopt_5fnodelete',['PL_OPT_NODELETE',['../plplot_8h.html#a3d2bbd2fc483c213fa2e44e34de74ed2',1,'plplot.h']]],
  ['pl_5fopt_5fstring',['PL_OPT_STRING',['../plplot_8h.html#ac95d3968abf030b28ebe3bc0437bc6a6',1,'plplot.h']]],
  ['pl_5fparse_5ffull',['PL_PARSE_FULL',['../plplot_8h.html#a14479e41f2f0a4dbdb5a683497e861a2',1,'plplot.h']]],
  ['pl_5fparse_5fnodash',['PL_PARSE_NODASH',['../plplot_8h.html#aeca83fa81659438865c63b6b4f46108e',1,'plplot.h']]],
  ['pl_5fparse_5fnodelete',['PL_PARSE_NODELETE',['../plplot_8h.html#a8f24dc82fc35e1f787ec01d02b6a4534',1,'plplot.h']]],
  ['pl_5fparse_5fnoprogram',['PL_PARSE_NOPROGRAM',['../plplot_8h.html#af8f39dec3f5a833d10a432b8c44482ea',1,'plplot.h']]],
  ['pl_5fparse_5foverride',['PL_PARSE_OVERRIDE',['../plplot_8h.html#a89bd94ba9fbb2c3ab8118b3eeedb9ae9',1,'plplot.h']]],
  ['pl_5fparse_5fpartial',['PL_PARSE_PARTIAL',['../plplot_8h.html#ad22d9d607ab5f334a2df5f5dd74f98ff',1,'plplot.h']]],
  ['pl_5fparse_5fquiet',['PL_PARSE_QUIET',['../plplot_8h.html#a929d833ef4808699abce4588635bc657',1,'plplot.h']]],
  ['pl_5fparse_5fshowall',['PL_PARSE_SHOWALL',['../plplot_8h.html#a07c13cf8ba54ab33c7926207de969465',1,'plplot.h']]],
  ['pl_5fparse_5fskip',['PL_PARSE_SKIP',['../plplot_8h.html#a1b2086d2e30c2cc6e9856269b8e46c00',1,'plplot.h']]],
  ['pl_5fposition_5fbottom',['PL_POSITION_BOTTOM',['../plplot_8h.html#a070f403a976e42378aad22e51d1a5285',1,'plplot.h']]],
  ['pl_5fposition_5finside',['PL_POSITION_INSIDE',['../plplot_8h.html#aac38c988f1ba35e2e861fe87368a17b5',1,'plplot.h']]],
  ['pl_5fposition_5fleft',['PL_POSITION_LEFT',['../plplot_8h.html#aea8b06633788da6fbc6988f63d6ab0e5',1,'plplot.h']]],
  ['pl_5fposition_5foutside',['PL_POSITION_OUTSIDE',['../plplot_8h.html#a51a7b6a259eb2137fa1d3f63f2bc3513',1,'plplot.h']]],
  ['pl_5fposition_5fright',['PL_POSITION_RIGHT',['../plplot_8h.html#abbe12ba62ad2169d23202cbcd6514f02',1,'plplot.h']]],
  ['pl_5fposition_5fsubpage',['PL_POSITION_SUBPAGE',['../plplot_8h.html#a3f53fc4e08007a1ca37b22c9f659a500',1,'plplot.h']]],
  ['pl_5fposition_5ftop',['PL_POSITION_TOP',['../plplot_8h.html#a61ba83ff66013b10ec81bfb0e197f0cc',1,'plplot.h']]],
  ['pl_5fposition_5fviewport',['PL_POSITION_VIEWPORT',['../plplot_8h.html#a9dc2049533b981570e5c3bff8a54202b',1,'plplot.h']]],
  ['pl_5frgb_5fcolor',['PL_RGB_COLOR',['../plplotP_8h.html#ad47775023e283082d2274c196ba264b8',1,'plplotP.h']]],
  ['pl_5fsetcontlabelformat',['pl_setcontlabelformat',['../plplot_8h.html#a759b301d598ed5606f95d7f3cc44c9f7',1,'plplot.h']]],
  ['pl_5fsetcontlabelparam',['pl_setcontlabelparam',['../plplot_8h.html#aabf62307ee5da33616fb41cdf94241ec',1,'plplot.h']]],
  ['pl_5fsfont',['PL_SFONT',['../plplotP_8h.html#a3839f1d7a380f4ef20ebbddd7f275a27',1,'plplotP.h']]],
  ['pl_5fundefined',['PL_UNDEFINED',['../plplotP_8h.html#aad52408b58851dc6713a87f439d0d926',1,'plplotP.h']]],
  ['pl_5funused',['PL_UNUSED',['../plplot_8h.html#a7d5497a8bc266dc65d84f05403965fbd',1,'plplot.h']]],
  ['pl_5fuse_5fnamespace',['PL_USE_NAMESPACE',['../plConfig_8h.html#a38438bcfe34ee23b6c0d3f4bc66fd118',1,'plConfig.h']]],
  ['pl_5fwxwidgets_5fipc3',['PL_WXWIDGETS_IPC3',['../plplot__config_8h.html#a978aa51558d71c50dfaf34071b9aaeea',1,'plplot_config.h']]],
  ['pl_5fx_5faxis',['PL_X_AXIS',['../plplot_8h.html#a56a5fd49ef1fdbddaea6796d554a8ea2',1,'plplot.h']]],
  ['pl_5fxfont',['PL_XFONT',['../plplotP_8h.html#afa71ec0de00d1490f068a5a74903e07e',1,'plplotP.h']]],
  ['pl_5fy_5faxis',['PL_Y_AXIS',['../plplot_8h.html#a1112e4818b4e23d202362016b0f248e6',1,'plplot.h']]],
  ['pl_5fz_5faxis',['PL_Z_AXIS',['../plplot_8h.html#acdc5bdf8af5f76efe849b1e3367e8302',1,'plplot.h']]],
  ['pladv',['pladv',['../plplot_8h.html#ad2490b31759e486f52f36acc1d346e4e',1,'plplot.h']]],
  ['plarc',['plarc',['../plplot_8h.html#a896d0adf8f8b516b75fd79dd07d94a32',1,'plplot.h']]],
  ['plaxes',['plaxes',['../plplot_8h.html#a9140da57e3d272cb8db2541116b660d2',1,'plplot.h']]],
  ['plbin',['plbin',['../plplot_8h.html#adbe5e12f749fd2f03f62e4aabd0952d8',1,'plplot.h']]],
  ['plbop',['plbop',['../plplot_8h.html#a36146b1eb81a5b362c484ac79aad0d36',1,'plplot.h']]],
  ['plbox',['plbox',['../plplot_8h.html#af55a7619d9dc46406190e135ba1a2df2',1,'plplot.h']]],
  ['plbox3',['plbox3',['../plplot_8h.html#a176fa792ce37ba7708e257739db99242',1,'plplot.h']]],
  ['plbtime',['plbtime',['../plplot_8h.html#af90c75a8ebae3b6d85f9b03c8f03d520',1,'plplot.h']]],
  ['plcairo_5fdefault_5fx',['PLCAIRO_DEFAULT_X',['../cairo_8c.html#aab89b21a432d42a2b98a3d4a7c9333d5',1,'cairo.c']]],
  ['plcairo_5fdefault_5fy',['PLCAIRO_DEFAULT_Y',['../cairo_8c.html#a5fce6b69b5900e9c471f696cdcdd0e19',1,'cairo.c']]],
  ['plcalc_5fworld',['plcalc_world',['../plplot_8h.html#a591cb7ee0cde82ce351668aec53dd977',1,'plplot.h']]],
  ['plclear',['plclear',['../plplot_8h.html#a63bd1070520beaff11ae084e68bfa42f',1,'plplot.h']]],
  ['plcol0',['plcol0',['../plplot_8h.html#abe182603da58d374804b7e0e31bb64f5',1,'plplot.h']]],
  ['plcol1',['plcol1',['../plplot_8h.html#a198b30552fe0d9e3a2de4727e09fa7f4',1,'plplot.h']]],
  ['plcolorbar',['plcolorbar',['../plplot_8h.html#ac08f1d4f5ca20c5e4840aa01fb7e2f6c',1,'plplot.h']]],
  ['plconfigtime',['plconfigtime',['../plplot_8h.html#a7826895e589cd9c52a66ee1adae63696',1,'plplot.h']]],
  ['plcont',['plcont',['../plplot_8h.html#a900cfb770c6f4dbeb162c6c4aed35b13',1,'plplot.h']]],
  ['plcpstrm',['plcpstrm',['../plplot_8h.html#ac9f42bf9fcaf791c72b0c1152d8c2727',1,'plplot.h']]],
  ['plctime',['plctime',['../plplot_8h.html#a62b48f8c8943b09d19f6bbc75ceff1e6',1,'plplot.h']]],
  ['pld_5fbmpqt',['PLD_bmpqt',['../plDevs_8h.html#ad68cc9baaea52dc8947695df16a5cd45',1,'plDevs.h']]],
  ['pld_5fepscairo',['PLD_epscairo',['../plDevs_8h.html#a438a0783c60b30d0b8b5cac08d3e0bb2',1,'plDevs.h']]],
  ['pld_5fepsqt',['PLD_epsqt',['../plDevs_8h.html#ae1f7e10ccb83b15fd6dbbb54f91a751b',1,'plDevs.h']]],
  ['pld_5fextcairo',['PLD_extcairo',['../plDevs_8h.html#a0293d58f6385e6220eb731564391f718',1,'plDevs.h']]],
  ['pld_5fextqt',['PLD_extqt',['../plDevs_8h.html#a60493b354dd7651bafe23208937aed6c',1,'plDevs.h']]],
  ['pld_5fjpgqt',['PLD_jpgqt',['../plDevs_8h.html#a8346a6839e0f3eb400778f86bc6d0e6a',1,'plDevs.h']]],
  ['pld_5fmem',['PLD_mem',['../plDevs_8h.html#af7cc2be9d79431bd6a4f230f7b23bfa2',1,'plDevs.h']]],
  ['pld_5fmemcairo',['PLD_memcairo',['../plDevs_8h.html#ae3a546675ee1b2f4a1ff58e273e15d25',1,'plDevs.h']]],
  ['pld_5fmemqt',['PLD_memqt',['../plDevs_8h.html#ac147823be7c830d9553c8a3ff265756a',1,'plDevs.h']]],
  ['pld_5fntk',['PLD_ntk',['../plDevs_8h.html#a81e54ac11e54e494ab01b329239ff1ba',1,'plDevs.h']]],
  ['pld_5fnull',['PLD_null',['../plDevs_8h.html#a71e58b4ded8ae6beab3bcabcb8d029e0',1,'plDevs.h']]],
  ['pld_5fpdf',['PLD_pdf',['../plDevs_8h.html#a70505870e64fd56725497b8c3cdf8396',1,'plDevs.h']]],
  ['pld_5fpdfcairo',['PLD_pdfcairo',['../plDevs_8h.html#ac90d5368a9ccaabce48102854d5efc4f',1,'plDevs.h']]],
  ['pld_5fpdfqt',['PLD_pdfqt',['../plDevs_8h.html#aba4a32298af75ebcfde5600e9e8cbb3a',1,'plDevs.h']]],
  ['pld_5fpngcairo',['PLD_pngcairo',['../plDevs_8h.html#a487def092729b41d2990e353647c413d',1,'plDevs.h']]],
  ['pld_5fpngqt',['PLD_pngqt',['../plDevs_8h.html#a5eeb7c3e7207c2a446aa6dec78fdd878',1,'plDevs.h']]],
  ['pld_5fppmqt',['PLD_ppmqt',['../plDevs_8h.html#af687e8b8da0d8405796aaaaadac40189',1,'plDevs.h']]],
  ['pld_5fps',['PLD_ps',['../plDevs_8h.html#a4696047dc34c94b449c94cfb57251b84',1,'plDevs.h']]],
  ['pld_5fpscairo',['PLD_pscairo',['../plDevs_8h.html#ae8c59bcfdfec6ecaae58e43eb3dbd5ae',1,'plDevs.h']]],
  ['pld_5fpsttf',['PLD_psttf',['../plDevs_8h.html#a47a3f3906dc4ce4382c8bb30b397d4db',1,'plDevs.h']]],
  ['pld_5fqtwidget',['PLD_qtwidget',['../plDevs_8h.html#adf31ffa1b2c2aafd65217caf31f84b69',1,'plDevs.h']]],
  ['pld_5fsvg',['PLD_svg',['../plDevs_8h.html#aff516eaaa04ea1d86619429cebab1f22',1,'plDevs.h']]],
  ['pld_5fsvgcairo',['PLD_svgcairo',['../plDevs_8h.html#a9398cd0089cd162a8607f22de8448871',1,'plDevs.h']]],
  ['pld_5fsvgqt',['PLD_svgqt',['../plDevs_8h.html#a32c8b3e83ed70d3760a9e8d2a4f4305c',1,'plDevs.h']]],
  ['pld_5ftiffqt',['PLD_tiffqt',['../plDevs_8h.html#afe8fd6ff145891b15b9eb8d6045519ef',1,'plDevs.h']]],
  ['pld_5ftk',['PLD_tk',['../plDevs_8h.html#a1e1fdf4cd01fc33ea9a2db279bef7d3f',1,'plDevs.h']]],
  ['pld_5ftkwin',['PLD_tkwin',['../plDevs_8h.html#ab19fba63e4f352c0bca5827dea2fe89d',1,'plDevs.h']]],
  ['pld_5fwxwidgets',['PLD_wxwidgets',['../plDevs_8h.html#a379f018c2bfed5c77e73ac42511d2ae2',1,'plDevs.h']]],
  ['pld_5fxcairo',['PLD_xcairo',['../plDevs_8h.html#a2ec08f682bd0dabeb204b4325e95f96a',1,'plDevs.h']]],
  ['pld_5fxfig',['PLD_xfig',['../plDevs_8h.html#a38323998bda2fa7561b19f02aa97289a',1,'plDevs.h']]],
  ['pld_5fxwin',['PLD_xwin',['../plDevs_8h.html#ad36dcafb053440ae52a61f9ba84efd63',1,'plDevs.h']]],
  ['pldi_5fdev',['PLDI_DEV',['../plplotP_8h.html#a5e4bab44736acafb8eeab671d011e9ce',1,'plplotP.h']]],
  ['pldi_5fmap',['PLDI_MAP',['../plplotP_8h.html#a18c9e4a6b0aa1780aa6e72d4a54ad3f3',1,'plplotP.h']]],
  ['pldi_5fori',['PLDI_ORI',['../plplotP_8h.html#aa3fb844c1173fb26470f3b9386567fe1',1,'plplotP.h']]],
  ['pldi_5fplt',['PLDI_PLT',['../plplotP_8h.html#ae0216a36024534929c94ff732870ff90',1,'plplotP.h']]],
  ['pldllexport',['PLDLLEXPORT',['../pldll_8h.html#abf3b7edf7783a56bee7b4782591ae67e',1,'pldll.h']]],
  ['pldllimpexp',['PLDLLIMPEXP',['../pldll_8h.html#ab06d18e197ef23613097fe90db7c33b2',1,'pldll.h']]],
  ['pldllimpexp_5fcxx',['PLDLLIMPEXP_CXX',['../pldll_8h.html#a559d9ae087a7f557709beb66970eab81',1,'pldll.h']]],
  ['pldllimpexp_5fcxx_5fdata',['PLDLLIMPEXP_CXX_DATA',['../pldll_8h.html#a15e4d6c8533569bf6757d5b5e3bb66c9',1,'pldll.h']]],
  ['pldllimpexp_5fdata',['PLDLLIMPEXP_DATA',['../pldll_8h.html#a00b57362a33448d57f58ad8c9c39b80c',1,'pldll.h']]],
  ['pldllimpexp_5fdriver',['PLDLLIMPEXP_DRIVER',['../pldll_8h.html#af9bec706108ea4c17c55222a4a2899f3',1,'pldll.h']]],
  ['pldllimpexp_5fdriver_5fdata',['PLDLLIMPEXP_DRIVER_DATA',['../pldll_8h.html#a593250b83d4303fb58bcb8b4ca17f6ac',1,'pldll.h']]],
  ['pldllimpexp_5ffortranc',['PLDLLIMPEXP_FORTRANC',['../pldll_8h.html#a842f1eb32e448f33ad7b2c77520cb57d',1,'pldll.h']]],
  ['pldllimpexp_5ffortranc_5fdata',['PLDLLIMPEXP_FORTRANC_DATA',['../pldll_8h.html#a640ed3869f78bbcad3bb92b8a3fd88e3',1,'pldll.h']]],
  ['pldllimpexp_5fpyqt4',['PLDLLIMPEXP_PYQT4',['../pldll_8h.html#a87f5399c8969b2cce703051418a4c2ee',1,'pldll.h']]],
  ['pldllimpexp_5fpyqt4_5fdata',['PLDLLIMPEXP_PYQT4_DATA',['../pldll_8h.html#aae6c49bfd5cf09716169dc21a4756977',1,'pldll.h']]],
  ['pldllimpexp_5fpyqt5',['PLDLLIMPEXP_PYQT5',['../pldll_8h.html#ad965cc839f8e4aa18b9b47a617faf266',1,'pldll.h']]],
  ['pldllimpexp_5fpyqt5_5fdata',['PLDLLIMPEXP_PYQT5_DATA',['../pldll_8h.html#a2dabc847a1b02ebb075ee3aefb10be41',1,'pldll.h']]],
  ['pldllimpexp_5fqt',['PLDLLIMPEXP_QT',['../pldll_8h.html#a6915811b91eb46629689336b388f65f2',1,'pldll.h']]],
  ['pldllimpexp_5fqt_5fdata',['PLDLLIMPEXP_QT_DATA',['../pldll_8h.html#af40a3f217ca0a8ae5ddaab86ee0b41ff',1,'pldll.h']]],
  ['pldllimpexp_5ftclmat',['PLDLLIMPEXP_TCLMAT',['../pldll_8h.html#a9914f90ab83c9a6e3beb39d2a95260d2',1,'pldll.h']]],
  ['pldllimpexp_5ftclmat_5fdata',['PLDLLIMPEXP_TCLMAT_DATA',['../pldll_8h.html#aaed20f25416f537c62e8fd377c8a4a69',1,'pldll.h']]],
  ['pldllimpexp_5ftcltk',['PLDLLIMPEXP_TCLTK',['../pldll_8h.html#aeb99673267fbf612476609af83d61e81',1,'pldll.h']]],
  ['pldllimpexp_5ftcltk_5fdata',['PLDLLIMPEXP_TCLTK_DATA',['../pldll_8h.html#a1da0425d1b55cc958413f1a42c8e16fb',1,'pldll.h']]],
  ['pldllimpexp_5fwx',['PLDLLIMPEXP_WX',['../pldll_8h.html#a3d355832b4c1ecf49005824a9e991898',1,'pldll.h']]],
  ['pldllimpexp_5fwx_5fdata',['PLDLLIMPEXP_WX_DATA',['../pldll_8h.html#a8fbd47a435d8f9bb0fad2a407257bd54',1,'pldll.h']]],
  ['pldllimport',['PLDLLIMPORT',['../pldll_8h.html#af83357c100315124a747641863164368',1,'pldll.h']]],
  ['plend',['plend',['../plplot_8h.html#aee9aeb2fb5c1888c307b74910dab6800',1,'plplot.h']]],
  ['plend1',['plend1',['../plplot_8h.html#ad9122365d79d7b45c78da65c09f7e1c9',1,'plplot.h']]],
  ['plenv',['plenv',['../plplot_8h.html#a27c648f17a51851ba7a3538d20a98f48',1,'plplot.h']]],
  ['plenv0',['plenv0',['../plplot_8h.html#a4d74b2c507e688f57bf0bb82a3608d69',1,'plplot.h']]],
  ['pleop',['pleop',['../plplot_8h.html#a0cba424c4c58ca5b60b474917d42d2b5',1,'plplot.h']]],
  ['plerrx',['plerrx',['../plplot_8h.html#a1267f751a55fbf9af59a9f5cb66241c3',1,'plplot.h']]],
  ['plerry',['plerry',['../plplot_8h.html#a07f65d6478ffa4353de099f7a250706b',1,'plplot.h']]],
  ['plesc_5falloc_5fncol',['PLESC_ALLOC_NCOL',['../plplot_8h.html#ae87f50d83b1fa81c85e641ff1603b087',1,'plplot.h']]],
  ['plesc_5fappend_5fbuffer',['PLESC_APPEND_BUFFER',['../plplot_8h.html#a9f071fd6195ce50d251d76e9e19ebe1a',1,'plplot.h']]],
  ['plesc_5farc',['PLESC_ARC',['../plplot_8h.html#ac183a5dea6e2d74c914fbfd683707851',1,'plplot.h']]],
  ['plesc_5fbegin_5ftext',['PLESC_BEGIN_TEXT',['../plplot_8h.html#ad60423577a77dfdc57cffefcb95fdcd8',1,'plplot.h']]],
  ['plesc_5fclear',['PLESC_CLEAR',['../plplot_8h.html#aa499059ba6f588b9034a61d071e9caa7',1,'plplot.h']]],
  ['plesc_5fcontrol_5fchar',['PLESC_CONTROL_CHAR',['../plplot_8h.html#a1c35044344b3eb8bb850f25d7dc3f1b8',1,'plplot.h']]],
  ['plesc_5fdash',['PLESC_DASH',['../plplot_8h.html#ab914590b71216f57f420a85083efa0ac',1,'plplot.h']]],
  ['plesc_5fdev2plcol',['PLESC_DEV2PLCOL',['../plplot_8h.html#a19eb29f519ab16f112122a5471800e49',1,'plplot.h']]],
  ['plesc_5fdevinit',['PLESC_DEVINIT',['../plplot_8h.html#a63307df7061d9e7dd3e32ce26edb9839',1,'plplot.h']]],
  ['plesc_5fdi',['PLESC_DI',['../plplot_8h.html#a85d3543f7602f5dd6d883dfdc1a0bd29',1,'plplot.h']]],
  ['plesc_5fdoublebuffering',['PLESC_DOUBLEBUFFERING',['../plplot_8h.html#ae0ba67569d3c270f7161e72c6f5cb514',1,'plplot.h']]],
  ['plesc_5fdoublebuffering_5fdisable',['PLESC_DOUBLEBUFFERING_DISABLE',['../plplot_8h.html#aa832b81650fc3ea47048d5882f089797',1,'plplot.h']]],
  ['plesc_5fdoublebuffering_5fenable',['PLESC_DOUBLEBUFFERING_ENABLE',['../plplot_8h.html#afa4d34c5d6c58fcf3d7ef4d027566314',1,'plplot.h']]],
  ['plesc_5fdoublebuffering_5fquery',['PLESC_DOUBLEBUFFERING_QUERY',['../plplot_8h.html#a19824499a04b0568256bbf3c27ae2b9e',1,'plplot.h']]],
  ['plesc_5feh',['PLESC_EH',['../plplot_8h.html#a5982ba3fe561d3c0060b58fa4f40479a',1,'plplot.h']]],
  ['plesc_5fend_5frasterize',['PLESC_END_RASTERIZE',['../plplot_8h.html#ae0382fba5d32e979cb384e714afa1518',1,'plplot.h']]],
  ['plesc_5fend_5ftext',['PLESC_END_TEXT',['../plplot_8h.html#a364fdd01ecc2c39ce6bf9068dcf55792',1,'plplot.h']]],
  ['plesc_5fexpose',['PLESC_EXPOSE',['../plplot_8h.html#a04ed603d88adb3cd41dafeb07df6eabf',1,'plplot.h']]],
  ['plesc_5ffill',['PLESC_FILL',['../plplot_8h.html#ab9b25e6e06dd0d6808371db0ddc0122a',1,'plplot.h']]],
  ['plesc_5ffixaspect',['PLESC_FIXASPECT',['../plplot_8h.html#a12543c8963759e9e89f2aeb6443dafce',1,'plplot.h']]],
  ['plesc_5fflush',['PLESC_FLUSH',['../plplot_8h.html#a77b55167b45bce03588d2893c466c368',1,'plplot.h']]],
  ['plesc_5fflush_5fremaining_5fbuffer',['PLESC_FLUSH_REMAINING_BUFFER',['../plplot_8h.html#ae9b11f35267bde0d224413a306edce35',1,'plplot.h']]],
  ['plesc_5fgetbackend',['PLESC_GETBACKEND',['../plplot_8h.html#ac4ab70a8f75aa95eba0de158d12f0d39',1,'plplot.h']]],
  ['plesc_5fgetc',['PLESC_GETC',['../plplot_8h.html#a0b36e6a122fbc4a47ff8ad9964f8623e',1,'plplot.h']]],
  ['plesc_5fgradient',['PLESC_GRADIENT',['../plplot_8h.html#a58e75b2debc5ab66b18e0657d5e8bec0',1,'plplot.h']]],
  ['plesc_5fgraph',['PLESC_GRAPH',['../plplot_8h.html#a9f9b24c00dc6fe18f16e4a29110d7b43',1,'plplot.h']]],
  ['plesc_5fhas_5ftext',['PLESC_HAS_TEXT',['../plplot_8h.html#a15ec6c98c5588c218820831631daed82',1,'plplot.h']]],
  ['plesc_5fimage',['PLESC_IMAGE',['../plplot_8h.html#a7e3519bc3357c32808f4a40040e609f2',1,'plplot.h']]],
  ['plesc_5fimageops',['PLESC_IMAGEOPS',['../plplot_8h.html#ae89d843559d5d03418cb91d9b161334a',1,'plplot.h']]],
  ['plesc_5fimport_5fbuffer',['PLESC_IMPORT_BUFFER',['../plplot_8h.html#a14af57e7de42d1649bae2faed3b777c4',1,'plplot.h']]],
  ['plesc_5fmodeget',['PLESC_MODEGET',['../plplot_8h.html#a0e988a4161665369dd1e2e0973a0897d',1,'plplot.h']]],
  ['plesc_5fmodeset',['PLESC_MODESET',['../plplot_8h.html#ab82e66ba552dd95fd67c63a4ad8af76a',1,'plplot.h']]],
  ['plesc_5fpl2devcol',['PLESC_PL2DEVCOL',['../plplot_8h.html#a13460c5799a6e0d9f9d2374bcd304407',1,'plplot.h']]],
  ['plesc_5fredraw',['PLESC_REDRAW',['../plplot_8h.html#afc62814c6cba9cfcfa58239d29e70a8a',1,'plplot.h']]],
  ['plesc_5fresize',['PLESC_RESIZE',['../plplot_8h.html#ab00b3464c4d58d86649631e3113a6723',1,'plplot.h']]],
  ['plesc_5fset_5fcompression',['PLESC_SET_COMPRESSION',['../plplot_8h.html#a3385d16b283bcad8ca9b25accd538986',1,'plplot.h']]],
  ['plesc_5fset_5flpb',['PLESC_SET_LPB',['../plplot_8h.html#afcdd11d53ce7e52d751f08d708ae301c',1,'plplot.h']]],
  ['plesc_5fset_5frgb',['PLESC_SET_RGB',['../plplot_8h.html#a85e4f9d6bb3b679fb11b37c1c46837d0',1,'plplot.h']]],
  ['plesc_5fsetbgfg',['PLESC_SETBGFG',['../plplot_8h.html#a4449949f5281a60c54a7243dff2e1d89',1,'plplot.h']]],
  ['plesc_5fstart_5frasterize',['PLESC_START_RASTERIZE',['../plplot_8h.html#a37f97e612914d22b55502c4fc5b2e22e',1,'plplot.h']]],
  ['plesc_5fswin',['PLESC_SWIN',['../plplot_8h.html#ad0bc9a1a9333fcadecf61263761b7409',1,'plplot.h']]],
  ['plesc_5ftext',['PLESC_TEXT',['../plplot_8h.html#a15ab7e866686a787b33fa38dbd9fc636',1,'plplot.h']]],
  ['plesc_5ftext_5fchar',['PLESC_TEXT_CHAR',['../plplot_8h.html#a944d357f5952fdad522b30f01c7d48b9',1,'plplot.h']]],
  ['plesc_5fxormod',['PLESC_XORMOD',['../plplot_8h.html#ad0f128389461f7249f2e627dba34dd90',1,'plplot.h']]],
  ['plfamadv',['plfamadv',['../plplot_8h.html#a964d8c7c1f00a1c5d0bab7a6d51f4fde',1,'plplot.h']]],
  ['plfill',['plfill',['../plplot_8h.html#a10221007d2c08a7117a70abab63dca51',1,'plplot.h']]],
  ['plfill3',['plfill3',['../plplot_8h.html#ad51faec84e8ab250bfdd2cdbea9bd331',1,'plplot.h']]],
  ['plflt2coord',['PLFLT2COORD',['../plmetafile_8c.html#a40efca8265e3ee8f3c8d0dde8cbd3e31',1,'plmetafile.c']]],
  ['plflt_5fmax',['PLFLT_MAX',['../plplot_8h.html#a83342f0fa1e35b8979af38fb349ae5ed',1,'plplot.h']]],
  ['plflt_5fmin',['PLFLT_MIN',['../plplot_8h.html#a3d84581230aacab980c3b57c09ec0ab9',1,'plplot.h']]],
  ['plflush',['plflush',['../plplot_8h.html#ae58d2db18a9da35dc75fa895fd9c6fcc',1,'plplot.h']]],
  ['plfont',['plfont',['../plplot_8h.html#a97607eb1064d82090f15c0ee2390c45a',1,'plplot.h']]],
  ['plfontld',['plfontld',['../plplot_8h.html#a04be3bb74b27838f83190c31ed82cc55',1,'plplot.h']]],
  ['plframe_5fcmd',['plframe_cmd',['../plframe_8c.html#a7fd00298d63e9105c46b320571d29661',1,'plframe.c']]],
  ['plgchr',['plgchr',['../plplot_8h.html#a1fb73af49c9abb537c88ea393752155e',1,'plplot.h']]],
  ['plgcmap1_5frange',['plgcmap1_range',['../plplot_8h.html#af45063acaef7672d33f91d358e8819cc',1,'plplot.h']]],
  ['plgcol0',['plgcol0',['../plplot_8h.html#ad1c197bc82bbf5f239c00e56efe9a794',1,'plplot.h']]],
  ['plgcol0a',['plgcol0a',['../plplot_8h.html#aa50fe6e48a8a48e484d0a4f262c71156',1,'plplot.h']]],
  ['plgcolbg',['plgcolbg',['../plplot_8h.html#af3e0cb65c7508fcab65794cf7dc0bbee',1,'plplot.h']]],
  ['plgcolbga',['plgcolbga',['../plplot_8h.html#ad25e012477db10ea1f90756fb6208303',1,'plplot.h']]],
  ['plgcompression',['plgcompression',['../plplot_8h.html#ad5a7e890ec11e05b1f5d430eec5751ee',1,'plplot.h']]],
  ['plgdev',['plgdev',['../plplot_8h.html#a55164c54e6208aa665129e950963da2c',1,'plplot.h']]],
  ['plgdidev',['plgdidev',['../plplot_8h.html#a3858e982a9c0b369fcd3cc12d7b12e59',1,'plplot.h']]],
  ['plgdiori',['plgdiori',['../plplot_8h.html#a4480b3c945c92a81912063a9218ccfef',1,'plplot.h']]],
  ['plgdiplt',['plgdiplt',['../plplot_8h.html#a1158e56e4321e7570ca83f6d2bd08345',1,'plplot.h']]],
  ['plgdrawmode',['plgdrawmode',['../plplot_8h.html#a55d10b752101ce0a68aaf9eb1e20283f',1,'plplot.h']]],
  ['plgfam',['plgfam',['../plplot_8h.html#ad7c9cfedfc5a36fcd675e30f92f60fb1',1,'plplot.h']]],
  ['plgfci',['plgfci',['../plplot_8h.html#a015820318be8e09a9664a9e540fcbd46',1,'plplot.h']]],
  ['plgfnam',['plgfnam',['../plplot_8h.html#a445776ffaf078452f9171468e067cbb6',1,'plplot.h']]],
  ['plgfont',['plgfont',['../plplot_8h.html#a27c0a3c27f2a1ca64fe978086c86e21f',1,'plplot.h']]],
  ['plglevel',['plglevel',['../plplot_8h.html#a947cb023f2648b03f042576690209482',1,'plplot.h']]],
  ['plgpage',['plgpage',['../plplot_8h.html#afb6efc36c176f36538d4c186d072a216',1,'plplot.h']]],
  ['plgra',['plgra',['../plplot_8h.html#a4d47a7b1078298c9b8ae22ab1fcec98a',1,'plplot.h']]],
  ['plgradient',['plgradient',['../plplot_8h.html#a568e78dcd391b4433859b890dadd4d9d',1,'plplot.h']]],
  ['plgriddata',['plgriddata',['../plplot_8h.html#aaae873adc73393d0ddb5fd9a2bb45f55',1,'plplot.h']]],
  ['plgspa',['plgspa',['../plplot_8h.html#a2eedb4af19a32fa71ad9502c3ff3a9b9',1,'plplot.h']]],
  ['plgstrm',['plgstrm',['../plplot_8h.html#a01686a7fe5b616111be053559e38ac4d',1,'plplot.h']]],
  ['plgver',['plgver',['../plplot_8h.html#a25f066a9f0bcde8a84b916f851c934e9',1,'plplot.h']]],
  ['plgvpd',['plgvpd',['../plplot_8h.html#a72115cfeb56478b5013f5255f56e40f9',1,'plplot.h']]],
  ['plgvpw',['plgvpw',['../plplot_8h.html#a89a25f49551295ebaa7659891310b801',1,'plplot.h']]],
  ['plgxax',['plgxax',['../plplot_8h.html#a4b6826699337d378e9afd1f78ee7ab56',1,'plplot.h']]],
  ['plgyax',['plgyax',['../plplot_8h.html#af9f80e861f700933d9a6fc15a5819e20',1,'plplot.h']]],
  ['plgzax',['plgzax',['../plplot_8h.html#ab32f3724f9d1c43e8377f5e18663feb7',1,'plplot.h']]],
  ['plhist',['plhist',['../plplot_8h.html#a3bdf138d9d1eb9ceacbebf7d3102a91e',1,'plplot.h']]],
  ['plhlsrgb',['plhlsrgb',['../plplot_8h.html#a7434c36a94f5227381b8516a6bcbb820',1,'plplot.h']]],
  ['plimage',['plimage',['../plplot_8h.html#a0dd73bcea5e0252ea3bac8a9738df485',1,'plplot.h']]],
  ['plimagefr',['plimagefr',['../plplot_8h.html#ad5f15675f7917b48ab8baccbbd6f5406',1,'plplot.h']]],
  ['plinit',['plinit',['../plplot_8h.html#a1301f8774e801284400f57b513d26300',1,'plplot.h']]],
  ['plint_5fmin',['PLINT_MIN',['../plplot_8h.html#a2051a514e3b3b49d1518f5c0004ecf42',1,'plplot.h']]],
  ['pljoin',['pljoin',['../plplot_8h.html#ab20325bf48b4b15b9513e38862e858c6',1,'plplot.h']]],
  ['plk_5falt_5fl',['PLK_Alt_L',['../plevent_8h.html#a7addbeef1412518d1281f67767b5aff5',1,'plevent.h']]],
  ['plk_5falt_5fr',['PLK_Alt_R',['../plevent_8h.html#a93839b5cc0b6c9d94022a00e16fb5923',1,'plevent.h']]],
  ['plk_5fbackspace',['PLK_BackSpace',['../plevent_8h.html#ade845cc8b8f8cd1ebb8fb0b8b1699fb7',1,'plevent.h']]],
  ['plk_5fbegin',['PLK_Begin',['../plevent_8h.html#a4a8c946f0f951e49a6b279b8f670bda5',1,'plevent.h']]],
  ['plk_5fbreak',['PLK_Break',['../plevent_8h.html#aae74b39d049228c17ef1ee7f5b38d262',1,'plevent.h']]],
  ['plk_5fcancel',['PLK_Cancel',['../plevent_8h.html#ab9d583429f66a6a5df74ddfa4b00ce98',1,'plevent.h']]],
  ['plk_5fcaps_5flock',['PLK_Caps_Lock',['../plevent_8h.html#a3f7e43f65ac4abbfce7588099cab1a2a',1,'plevent.h']]],
  ['plk_5fclear',['PLK_Clear',['../plevent_8h.html#ad71156f9c62b0b765bd4176de4a906eb',1,'plevent.h']]],
  ['plk_5fcontrol_5fl',['PLK_Control_L',['../plevent_8h.html#a067111ebbea77759e47b1e4e14fdd827',1,'plevent.h']]],
  ['plk_5fcontrol_5fr',['PLK_Control_R',['../plevent_8h.html#a84b1dd0a587c3bcd8fceb87f8b1b0e6e',1,'plevent.h']]],
  ['plk_5fdelete',['PLK_Delete',['../plevent_8h.html#ac2b0cfa9e51fadfcfa2c0d247e81085d',1,'plevent.h']]],
  ['plk_5fdown',['PLK_Down',['../plevent_8h.html#adeba75d26d24764ce1b405b05019e840',1,'plevent.h']]],
  ['plk_5fend',['PLK_End',['../plevent_8h.html#a54482f9f22529f5a683fbbbf880662d6',1,'plevent.h']]],
  ['plk_5fescape',['PLK_Escape',['../plevent_8h.html#afc23f1dab0da11fca8b095db5522475a',1,'plevent.h']]],
  ['plk_5fexecute',['PLK_Execute',['../plevent_8h.html#adeed314b63aed8b5e1262c563e54bdd8',1,'plevent.h']]],
  ['plk_5ff1',['PLK_F1',['../plevent_8h.html#a11d5b98e40036990dbd49b1fcb6429c9',1,'plevent.h']]],
  ['plk_5ff10',['PLK_F10',['../plevent_8h.html#a596c82510b2945796178a34a66783c13',1,'plevent.h']]],
  ['plk_5ff11',['PLK_F11',['../plevent_8h.html#a818d787340571f0dd90b675f749d171b',1,'plevent.h']]],
  ['plk_5ff12',['PLK_F12',['../plevent_8h.html#a4a2d4af34170127e3830590db203a846',1,'plevent.h']]],
  ['plk_5ff13',['PLK_F13',['../plevent_8h.html#ab05e1f6145e5b88c034fc425e2f5eb03',1,'plevent.h']]],
  ['plk_5ff14',['PLK_F14',['../plevent_8h.html#a3263b72f274e9647fd121ebb5e277b3c',1,'plevent.h']]],
  ['plk_5ff15',['PLK_F15',['../plevent_8h.html#ac253d3a5d8d1aca47b462649a18b5122',1,'plevent.h']]],
  ['plk_5ff16',['PLK_F16',['../plevent_8h.html#ad79607303130bfe2bd0ebb1c7bf71f56',1,'plevent.h']]],
  ['plk_5ff17',['PLK_F17',['../plevent_8h.html#a2e38cd76f53f27a1971811fe4fff8cf4',1,'plevent.h']]],
  ['plk_5ff18',['PLK_F18',['../plevent_8h.html#a5cf3510126f88fe8ae2bfc4581ede748',1,'plevent.h']]],
  ['plk_5ff19',['PLK_F19',['../plevent_8h.html#acca9ad5bf88aab7fcee50feefb2b97de',1,'plevent.h']]],
  ['plk_5ff2',['PLK_F2',['../plevent_8h.html#a7e9ee09f2768b2861d0bc7c65e451774',1,'plevent.h']]],
  ['plk_5ff20',['PLK_F20',['../plevent_8h.html#a6085b43928d012872cbf317ead06c99e',1,'plevent.h']]],
  ['plk_5ff21',['PLK_F21',['../plevent_8h.html#a785883cf406f600ba44515b47579b21f',1,'plevent.h']]],
  ['plk_5ff22',['PLK_F22',['../plevent_8h.html#a0733aa29c6eb7aeed145cf0cf9f8e853',1,'plevent.h']]],
  ['plk_5ff23',['PLK_F23',['../plevent_8h.html#a4ff86331fa7ca2fd1f74f040dcc440d0',1,'plevent.h']]],
  ['plk_5ff24',['PLK_F24',['../plevent_8h.html#a11cdd5bbfd7852121a6514730d16d519',1,'plevent.h']]],
  ['plk_5ff25',['PLK_F25',['../plevent_8h.html#a1f6351c845a21e9526522ce3d045e132',1,'plevent.h']]],
  ['plk_5ff26',['PLK_F26',['../plevent_8h.html#a6fc735c10b8c16e677087b96a03b0419',1,'plevent.h']]],
  ['plk_5ff27',['PLK_F27',['../plevent_8h.html#a26afa93b8db8ec6eb80e6beaa4c97910',1,'plevent.h']]],
  ['plk_5ff28',['PLK_F28',['../plevent_8h.html#a472b9c231be7ff526ec231eb46eafc59',1,'plevent.h']]],
  ['plk_5ff29',['PLK_F29',['../plevent_8h.html#a66be249c47ace90c14708edf6002a157',1,'plevent.h']]],
  ['plk_5ff3',['PLK_F3',['../plevent_8h.html#a9d382749473833a700afe99433a00ce0',1,'plevent.h']]],
  ['plk_5ff30',['PLK_F30',['../plevent_8h.html#a108004532654a27b1651854d7de116bf',1,'plevent.h']]],
  ['plk_5ff31',['PLK_F31',['../plevent_8h.html#aa2a05a9dfbad568ce803dd660744dcd1',1,'plevent.h']]],
  ['plk_5ff32',['PLK_F32',['../plevent_8h.html#a85852a34a9fbc0409b71bb8fa38aa577',1,'plevent.h']]],
  ['plk_5ff33',['PLK_F33',['../plevent_8h.html#aeb45993b46a0440bfd4d1bfc2ad2a842',1,'plevent.h']]],
  ['plk_5ff34',['PLK_F34',['../plevent_8h.html#ae73cc2c302ae0087bf316126e21c376a',1,'plevent.h']]],
  ['plk_5ff35',['PLK_F35',['../plevent_8h.html#a0599375395a6a000bfd803590dcbcffa',1,'plevent.h']]],
  ['plk_5ff4',['PLK_F4',['../plevent_8h.html#a9f9a8cc0e4e63a1de3d86c650e7f3ad8',1,'plevent.h']]],
  ['plk_5ff5',['PLK_F5',['../plevent_8h.html#afc4404208d3bd71015bfd5d1838038d0',1,'plevent.h']]],
  ['plk_5ff6',['PLK_F6',['../plevent_8h.html#a38daa05dd6d90916bc63d0b5a225a6b9',1,'plevent.h']]],
  ['plk_5ff7',['PLK_F7',['../plevent_8h.html#a3d947dd06e6d7b9f909129d8ecf0b7f9',1,'plevent.h']]],
  ['plk_5ff8',['PLK_F8',['../plevent_8h.html#a00fbe2e0eff4826f727d3b5403942c15',1,'plevent.h']]],
  ['plk_5ff9',['PLK_F9',['../plevent_8h.html#a5e1e6f18790d22e73de4e87e2ee91183',1,'plevent.h']]],
  ['plk_5ffind',['PLK_Find',['../plevent_8h.html#a18eab97f30eade11e47d5e31f1c17bde',1,'plevent.h']]],
  ['plk_5fhelp',['PLK_Help',['../plevent_8h.html#a8e82bfe4f6d40d8d0fabe53f3f1739ed',1,'plevent.h']]],
  ['plk_5fhome',['PLK_Home',['../plevent_8h.html#a69d15222fbb69852a446210a19f14316',1,'plevent.h']]],
  ['plk_5fhyper_5fl',['PLK_Hyper_L',['../plevent_8h.html#a92b136ce509b951b47ffc12c1a7e2056',1,'plevent.h']]],
  ['plk_5fhyper_5fr',['PLK_Hyper_R',['../plevent_8h.html#a4bac5a80639e5f01dcb8b703c48d185f',1,'plevent.h']]],
  ['plk_5finsert',['PLK_Insert',['../plevent_8h.html#a34628cc3069427b1f852eef00b2d64e2',1,'plevent.h']]],
  ['plk_5fkp_5f0',['PLK_KP_0',['../plevent_8h.html#a22eedffc20cc77dd63e3d141e7bddc29',1,'plevent.h']]],
  ['plk_5fkp_5f1',['PLK_KP_1',['../plevent_8h.html#aeeb53eb1ae422fda8e0267ed2f6c4c7a',1,'plevent.h']]],
  ['plk_5fkp_5f2',['PLK_KP_2',['../plevent_8h.html#a56ab9ec1896b7fc731fa677dee34581a',1,'plevent.h']]],
  ['plk_5fkp_5f3',['PLK_KP_3',['../plevent_8h.html#a03822bb7e633dd0b6fc1a4f1a2b9f84a',1,'plevent.h']]],
  ['plk_5fkp_5f4',['PLK_KP_4',['../plevent_8h.html#a36208fd0c8699d778d0fafe589278862',1,'plevent.h']]],
  ['plk_5fkp_5f5',['PLK_KP_5',['../plevent_8h.html#aaa8c6c3d64aeb53240aa1c5fd1b6f1d1',1,'plevent.h']]],
  ['plk_5fkp_5f6',['PLK_KP_6',['../plevent_8h.html#a94ee1e89324e1f166bfec5426e7f1f35',1,'plevent.h']]],
  ['plk_5fkp_5f7',['PLK_KP_7',['../plevent_8h.html#a091a7fb97ddaaa555e2ed54b17bc68b9',1,'plevent.h']]],
  ['plk_5fkp_5f8',['PLK_KP_8',['../plevent_8h.html#a7eba39395e1afb9d13baf6eeee20b86d',1,'plevent.h']]],
  ['plk_5fkp_5f9',['PLK_KP_9',['../plevent_8h.html#a0c500f1cdf3bc0cba50bf1bc6ad6a1ad',1,'plevent.h']]],
  ['plk_5fkp_5fadd',['PLK_KP_Add',['../plevent_8h.html#a67ca95a749147d5e628a84bb36745388',1,'plevent.h']]],
  ['plk_5fkp_5fdecimal',['PLK_KP_Decimal',['../plevent_8h.html#a9900cfdd4c970acb0c36bd0e4a3a2b5b',1,'plevent.h']]],
  ['plk_5fkp_5fdivide',['PLK_KP_Divide',['../plevent_8h.html#ab509acf5fe3f15c21d2814c68b1f0e9a',1,'plevent.h']]],
  ['plk_5fkp_5fenter',['PLK_KP_Enter',['../plevent_8h.html#ae5c767cced39d7bf26f565a175fc75c7',1,'plevent.h']]],
  ['plk_5fkp_5fequal',['PLK_KP_Equal',['../plevent_8h.html#a43a862fc778964aee8a84ab23bccc453',1,'plevent.h']]],
  ['plk_5fkp_5ff1',['PLK_KP_F1',['../plevent_8h.html#a87d4e864cd1b21efc9787afe73ede28e',1,'plevent.h']]],
  ['plk_5fkp_5ff2',['PLK_KP_F2',['../plevent_8h.html#a90645e4aa4afeb5c96823c9512b6790e',1,'plevent.h']]],
  ['plk_5fkp_5ff3',['PLK_KP_F3',['../plevent_8h.html#a2380d0de20c7bd8b635f340d4347ebd4',1,'plevent.h']]],
  ['plk_5fkp_5ff4',['PLK_KP_F4',['../plevent_8h.html#ac0dcc2094e7972ae4a4f28a9916fccb1',1,'plevent.h']]],
  ['plk_5fkp_5fmultiply',['PLK_KP_Multiply',['../plevent_8h.html#ae062b4d223e2a2857605508887f91dde',1,'plevent.h']]],
  ['plk_5fkp_5fseparator',['PLK_KP_Separator',['../plevent_8h.html#acaef5aa8ffd11c76cf4971a8cee21903',1,'plevent.h']]],
  ['plk_5fkp_5fspace',['PLK_KP_Space',['../plevent_8h.html#a507d39cdec712f36bb1cc0fc3a33ec0d',1,'plevent.h']]],
  ['plk_5fkp_5fsubtract',['PLK_KP_Subtract',['../plevent_8h.html#a51a543bd1cd82c7327056d2f7eacb196',1,'plevent.h']]],
  ['plk_5fkp_5ftab',['PLK_KP_Tab',['../plevent_8h.html#a7963a329b2fbc56ebf0e553cd466727d',1,'plevent.h']]],
  ['plk_5fl1',['PLK_L1',['../plevent_8h.html#aae40dd3c80f32f844aed8b223a0303ac',1,'plevent.h']]],
  ['plk_5fl10',['PLK_L10',['../plevent_8h.html#aa428784e460662302cee237c427040ac',1,'plevent.h']]],
  ['plk_5fl2',['PLK_L2',['../plevent_8h.html#a54e804c263ab747440c211dc3ed52511',1,'plevent.h']]],
  ['plk_5fl3',['PLK_L3',['../plevent_8h.html#a716391e7ea7124a1defe09e75116a19e',1,'plevent.h']]],
  ['plk_5fl4',['PLK_L4',['../plevent_8h.html#a2afbc20dc6833bfe66a4414238637ea1',1,'plevent.h']]],
  ['plk_5fl5',['PLK_L5',['../plevent_8h.html#a8f6f2c94e0ac42f303b0d4380138ee23',1,'plevent.h']]],
  ['plk_5fl6',['PLK_L6',['../plevent_8h.html#a6c2ab05215371b927ba3b5310c5d1ea2',1,'plevent.h']]],
  ['plk_5fl7',['PLK_L7',['../plevent_8h.html#aa347fbec39853e564d90d9cf7ef0c544',1,'plevent.h']]],
  ['plk_5fl8',['PLK_L8',['../plevent_8h.html#af1387bab10ebe001d3845a283fbe6d33',1,'plevent.h']]],
  ['plk_5fl9',['PLK_L9',['../plevent_8h.html#a3af74a4f7549ac020ef033c89386ed45',1,'plevent.h']]],
  ['plk_5fleft',['PLK_Left',['../plevent_8h.html#ae78f2cf9f204a7d1ba8a72d8f54e311c',1,'plevent.h']]],
  ['plk_5flinefeed',['PLK_Linefeed',['../plevent_8h.html#affa3369cef37cc9a221a801c2d0e6db1',1,'plevent.h']]],
  ['plk_5fmenu',['PLK_Menu',['../plevent_8h.html#ac865a8aa504df9f0a117135c7a3f7a19',1,'plevent.h']]],
  ['plk_5fmeta_5fl',['PLK_Meta_L',['../plevent_8h.html#a9bd9b8126e0257ecaeb42ea615f2289e',1,'plevent.h']]],
  ['plk_5fmeta_5fr',['PLK_Meta_R',['../plevent_8h.html#abd9540b5c13eeafacc4373a40c7c6f8a',1,'plevent.h']]],
  ['plk_5fmode_5fswitch',['PLK_Mode_switch',['../plevent_8h.html#adff3a309613333109f7cbd0ec62bde40',1,'plevent.h']]],
  ['plk_5fnext',['PLK_Next',['../plevent_8h.html#a44bbcc909f09a88f64790ebaf881caca',1,'plevent.h']]],
  ['plk_5fnum_5flock',['PLK_Num_Lock',['../plevent_8h.html#a4e765708c53e7d3a587c4fb71bc604e8',1,'plevent.h']]],
  ['plk_5fpause',['PLK_Pause',['../plevent_8h.html#a69a5ba47a0af9851a2b0b716e6a72dcc',1,'plevent.h']]],
  ['plk_5fprint',['PLK_Print',['../plevent_8h.html#a1212723031a35ad4c176739c52973627',1,'plevent.h']]],
  ['plk_5fprior',['PLK_Prior',['../plevent_8h.html#a5b8eca98ef2a41ecbf663a2623421957',1,'plevent.h']]],
  ['plk_5fr1',['PLK_R1',['../plevent_8h.html#af7f292dadc190612051bdba70daa1b31',1,'plevent.h']]],
  ['plk_5fr10',['PLK_R10',['../plevent_8h.html#ad6481b44926c80cc592fd2cb6da273c1',1,'plevent.h']]],
  ['plk_5fr11',['PLK_R11',['../plevent_8h.html#a731917567f01e4b9526ae251a7527717',1,'plevent.h']]],
  ['plk_5fr12',['PLK_R12',['../plevent_8h.html#afcae252b323106fa8df5324a5754f013',1,'plevent.h']]],
  ['plk_5fr13',['PLK_R13',['../plevent_8h.html#aad85b54dc2f711f2b96a1226bbbd1fda',1,'plevent.h']]],
  ['plk_5fr14',['PLK_R14',['../plevent_8h.html#a00769d30a82eea78bf58ff3b7345c798',1,'plevent.h']]],
  ['plk_5fr15',['PLK_R15',['../plevent_8h.html#a0f65c8dbc382fe82cd0c68fd4c95c7af',1,'plevent.h']]],
  ['plk_5fr2',['PLK_R2',['../plevent_8h.html#a36d02a91f6bb61020ac83964302e08e8',1,'plevent.h']]],
  ['plk_5fr3',['PLK_R3',['../plevent_8h.html#a16b839a69c5b5adc37508df2b73e44ac',1,'plevent.h']]],
  ['plk_5fr4',['PLK_R4',['../plevent_8h.html#a6b91f3519a6f81a11aa0e682a3f4729a',1,'plevent.h']]],
  ['plk_5fr5',['PLK_R5',['../plevent_8h.html#a539a0ad508a066408105d9c0c0899d5a',1,'plevent.h']]],
  ['plk_5fr6',['PLK_R6',['../plevent_8h.html#a902f8f12005147c3c8bde06a81284476',1,'plevent.h']]],
  ['plk_5fr7',['PLK_R7',['../plevent_8h.html#a81d87462b8b34d4a959569afd99a2a9e',1,'plevent.h']]],
  ['plk_5fr8',['PLK_R8',['../plevent_8h.html#aeba4347e069a295a0ad38b1b1c2785c2',1,'plevent.h']]],
  ['plk_5fr9',['PLK_R9',['../plevent_8h.html#adad3dffe289b50d92dc86a96396e8b06',1,'plevent.h']]],
  ['plk_5fredo',['PLK_Redo',['../plevent_8h.html#a2d7181bdd9853a3b5ba92a886892f7f6',1,'plevent.h']]],
  ['plk_5freturn',['PLK_Return',['../plevent_8h.html#adace01527c36f54c1f300eac3f4ed957',1,'plevent.h']]],
  ['plk_5fright',['PLK_Right',['../plevent_8h.html#af26978fd5e5b43b29219033c2bfffa77',1,'plevent.h']]],
  ['plk_5fscript_5fswitch',['PLK_script_switch',['../plevent_8h.html#a3ee00eb941f8337a4bf4377c58b6d517',1,'plevent.h']]],
  ['plk_5fscroll_5flock',['PLK_Scroll_Lock',['../plevent_8h.html#a80d6fc6043dad6edfa882974afb82e9f',1,'plevent.h']]],
  ['plk_5fselect',['PLK_Select',['../plevent_8h.html#a17951fcf478154416d2937667ca8e5a7',1,'plevent.h']]],
  ['plk_5fshift_5fl',['PLK_Shift_L',['../plevent_8h.html#a3a79cdfe9b36a998655c0b2e180b2c1f',1,'plevent.h']]],
  ['plk_5fshift_5flock',['PLK_Shift_Lock',['../plevent_8h.html#a5fe61ad9970f37dcbb6e1b55ace2581d',1,'plevent.h']]],
  ['plk_5fshift_5fr',['PLK_Shift_R',['../plevent_8h.html#a3d7730b2adab26219bea9d90614b2ae8',1,'plevent.h']]],
  ['plk_5fsuper_5fl',['PLK_Super_L',['../plevent_8h.html#ac02980112d6d36eb289b0e02a5eb4119',1,'plevent.h']]],
  ['plk_5fsuper_5fr',['PLK_Super_R',['../plevent_8h.html#a6bdb28760e49663a31729c00c0685397',1,'plevent.h']]],
  ['plk_5ftab',['PLK_Tab',['../plevent_8h.html#a1da99c6f64ce6676bde91905ccacbb92',1,'plevent.h']]],
  ['plk_5fundo',['PLK_Undo',['../plevent_8h.html#a102a3b57f9124d175b3b23e2547c2a76',1,'plevent.h']]],
  ['plk_5fup',['PLK_Up',['../plevent_8h.html#a86d9a566916d1df494a435ce527b2133',1,'plevent.h']]],
  ['pllab',['pllab',['../plplot_8h.html#a5b2cc40d2ebfe0516a855bf94545ebdf',1,'plplot.h']]],
  ['pllegend',['pllegend',['../plplot_8h.html#a24934313f195bd9be45ea6269c488068',1,'plplot.h']]],
  ['pllibdev',['PLLIBDEV',['../plctrl_8c.html#a2bb1f3e447dbbab7fcad2ada6dba7539',1,'plctrl.c']]],
  ['pllightsource',['pllightsource',['../plplot_8h.html#a298751e5ef41696842b542ad92ca6bba',1,'plplot.h']]],
  ['plline',['plline',['../plplot_8h.html#ab1e6d3fe50dfbda05b419be4ce2052b2',1,'plplot.h']]],
  ['plline3',['plline3',['../plplot_8h.html#ad3a891ae7d8092eef6afbdd75b775885',1,'plplot.h']]],
  ['pllsty',['pllsty',['../plplot_8h.html#a92c6f5898168b542f4dc9b0dee69832c',1,'plplot.h']]],
  ['plm_5frd',['plm_rd',['../metadefs_8h.html#ab3a6bd5ed1cbaae1db778d76abfbfed8',1,'metadefs.h']]],
  ['plm_5fwr',['plm_wr',['../metadefs_8h.html#a37389f4fb994c03c2206bd4103a8c16f',1,'metadefs.h']]],
  ['plmap',['plmap',['../plplot_8h.html#a0f8e566fd2a93bf828220f85ce8a0082',1,'plplot.h']]],
  ['plmapfill',['plmapfill',['../plplot_8h.html#a195d7a844dbb92a8f22001ec7c7af0d6',1,'plplot.h']]],
  ['plmapline',['plmapline',['../plplot_8h.html#a3f35026b66694311152c960424c4262a',1,'plplot.h']]],
  ['plmapstring',['plmapstring',['../plplot_8h.html#a7f527daa07872e6b78010ea7d672e08c',1,'plplot.h']]],
  ['plmaptex',['plmaptex',['../plplot_8h.html#a1e772d703253ac38dd80acadcc6b9b6b',1,'plplot.h']]],
  ['plmaxstr',['PLMAXSTR',['../plsym_8c.html#ab037d49a537914ba19b9b6fff5fd824f',1,'plsym.c']]],
  ['plmeridians',['plmeridians',['../plplot_8h.html#ac3173de283e0221191f9e2135799fc4a',1,'plplot.h']]],
  ['plmesh',['plmesh',['../plplot_8h.html#aefd07a6d456b4ba015defdcb92eec185',1,'plplot.h']]],
  ['plmeshc',['plmeshc',['../plplot_8h.html#aa81ce26dbf38805a61dad659e74a03e5',1,'plplot.h']]],
  ['plmeta_5fheader',['PLMETA_HEADER',['../metadefs_8h.html#a3bb571c4f11f5f5cb152e6e9433ad770',1,'metadefs.h']]],
  ['plmeta_5fversion',['PLMETA_VERSION',['../metadefs_8h.html#aa77188678f3303c33c7fae0656fd21aa',1,'metadefs.h']]],
  ['plmeta_5fx_5fold',['PLMETA_X_OLD',['../metadefs_8h.html#ac44208d4bf130212246788c731b99856',1,'metadefs.h']]],
  ['plmeta_5fy_5fold',['PLMETA_Y_OLD',['../metadefs_8h.html#ad1e3938b8d650bd072c3d32a88269406',1,'metadefs.h']]],
  ['plmkstrm',['plmkstrm',['../plplot_8h.html#acd26e5b27384f8ec5d44e41da906f68a',1,'plplot.h']]],
  ['plmtex',['plmtex',['../plplot_8h.html#aea8b2357c54cbeb5684fd5dc07969f81',1,'plplot.h']]],
  ['plmtex3',['plmtex3',['../plplot_8h.html#a624c8069961974c22666a0f030fd950c',1,'plplot.h']]],
  ['plot3d',['plot3d',['../plplot_8h.html#a81659c151bbdac841e21787c4c0b9e2f',1,'plplot.h']]],
  ['plot3dc',['plot3dc',['../plplot_8h.html#ac6331e4c060c22bb6d2b7a3f18927a26',1,'plplot.h']]],
  ['plot3dcl',['plot3dcl',['../plplot_8h.html#a6a3d8b43d766f770458376a19d44128a',1,'plplot.h']]],
  ['plparseopts',['plparseopts',['../plplot_8h.html#a7f34f76bda1bd5160d110e6f0ea314a5',1,'plplot.h']]],
  ['plpat',['plpat',['../plplot_8h.html#a02b63d4b5fa44eaadfabf992712d3694',1,'plplot.h']]],
  ['plpath',['plpath',['../plplot_8h.html#a055c4c882ea933b52e5d873f56c6a556',1,'plplot.h']]],
  ['plplot5_5ffonts',['PLPLOT5_FONTS',['../plplotP_8h.html#adddbf64c5ed632bfd3883b110cdf8fef',1,'plplotP.h']]],
  ['plplot_5fbin_5fenv',['PLPLOT_BIN_ENV',['../plplotP_8h.html#ac03c79ca8cd54fb9e7509706e7e68f0d',1,'plplotP.h']]],
  ['plplot_5fdefault_5fheight_5fmm',['PLPLOT_DEFAULT_HEIGHT_MM',['../plplotP_8h.html#ab2ace681fb9b3b392cba0f18bbe66071',1,'plplotP.h']]],
  ['plplot_5fdefault_5fheight_5fpixels',['PLPLOT_DEFAULT_HEIGHT_PIXELS',['../plplotP_8h.html#a9e67a9eef9de5dc820c06f92a4f344b1',1,'plplotP.h']]],
  ['plplot_5fdefault_5fheight_5fpoints',['PLPLOT_DEFAULT_HEIGHT_POINTS',['../plplotP_8h.html#a826fd901df2855ac98c9b33ec0b57fe3',1,'plplotP.h']]],
  ['plplot_5fdefault_5fpixels_5fper_5finch',['PLPLOT_DEFAULT_PIXELS_PER_INCH',['../plplotP_8h.html#ac3e74dd5ad2cabab8fe4652c29b6512b',1,'plplotP.h']]],
  ['plplot_5fdefault_5fwidth_5fmm',['PLPLOT_DEFAULT_WIDTH_MM',['../plplotP_8h.html#a1d6d7570fcd62267241708091023650e',1,'plplotP.h']]],
  ['plplot_5fdefault_5fwidth_5fpixels',['PLPLOT_DEFAULT_WIDTH_PIXELS',['../plplotP_8h.html#a91cb3228499847af3a270c7b6ad19eb7',1,'plplotP.h']]],
  ['plplot_5fdefault_5fwidth_5fpoints',['PLPLOT_DEFAULT_WIDTH_POINTS',['../plplotP_8h.html#a7fcdda9368b70cb7ca54f5a74efe16c5',1,'plplotP.h']]],
  ['plplot_5fextended_5fsearch',['PLPLOT_EXTENDED_SEARCH',['../tclAPI_8c.html#afc8996c89333709dccb6e53ddf203c69',1,'tclAPI.c']]],
  ['plplot_5fheight_5fa4_5fmm',['PLPLOT_HEIGHT_A4_MM',['../plplotP_8h.html#a90709d034193dd5dfdbdedcc8d393b54',1,'plplotP.h']]],
  ['plplot_5fheight_5fa5_5fmm',['PLPLOT_HEIGHT_A5_MM',['../plplotP_8h.html#a52ca90477cd17bcfc5315377db003d83',1,'plplotP.h']]],
  ['plplot_5fhome_5fenv',['PLPLOT_HOME_ENV',['../plplotP_8h.html#aa75c95ff00e85a94e00607777d07cae9',1,'plplotP.h']]],
  ['plplot_5fitcl_5fversion',['PLPLOT_ITCL_VERSION',['../plplot__config_8h.html#a76784a3a0851290e483a065288f8b5b5',1,'plplot_config.h']]],
  ['plplot_5fitk_5fversion',['PLPLOT_ITK_VERSION',['../plplot__config_8h.html#abbe468dce37890cb75a99d63ab27614f',1,'plplot_config.h']]],
  ['plplot_5fiwidgets_5fversion',['PLPLOT_IWIDGETS_VERSION',['../plplot__config_8h.html#a1f0da538ec079925a9cd0b2b2c218fac',1,'plplot_config.h']]],
  ['plplot_5flib_5fenv',['PLPLOT_LIB_ENV',['../plplotP_8h.html#a4d712860a546e16091b8bfa9b6fb355f',1,'plplotP.h']]],
  ['plplot_5fmax_5fpath',['PLPLOT_MAX_PATH',['../plplotP_8h.html#a0b360f193f449275cbdc9b36a756dd6c',1,'plplotP.h']]],
  ['plplot_5fmm_5fper_5finch',['PLPLOT_MM_PER_INCH',['../plplotP_8h.html#a3e57d03a5161d56776f4b8cbdd8532cc',1,'plplotP.h']]],
  ['plplot_5fmutex_5frecursive',['PLPLOT_MUTEX_RECURSIVE',['../plplot__config_8h.html#a1656194b16a39df9359ce8ec4ebb851e',1,'plplot_config.h']]],
  ['plplot_5fpoints_5fper_5finch',['PLPLOT_POINTS_PER_INCH',['../plplotP_8h.html#a49a32722e9dcc0e01c3b3faee3ed082e',1,'plplotP.h']]],
  ['plplot_5ftcl_5fenv',['PLPLOT_TCL_ENV',['../plplotP_8h.html#a7ec795052c6fe6de491ff626aae9a09b',1,'plplotP.h']]],
  ['plplot_5fversion',['PLPLOT_VERSION',['../plConfig_8h.html#ae0e22c058c258b6acce53c1dfa3aa2f7',1,'plConfig.h']]],
  ['plplot_5fversion_5fmajor',['PLPLOT_VERSION_MAJOR',['../plConfig_8h.html#a112cee99246ffbc75b38333bbe4de54b',1,'plConfig.h']]],
  ['plplot_5fversion_5fminor',['PLPLOT_VERSION_MINOR',['../plConfig_8h.html#ab93f2d5cd7570915e309faa0859986d5',1,'plConfig.h']]],
  ['plplot_5fversion_5fpatch',['PLPLOT_VERSION_PATCH',['../plConfig_8h.html#ab16d30c00314e3770daaae567531ae3b',1,'plConfig.h']]],
  ['plplot_5fwidth_5fa4_5fmm',['PLPLOT_WIDTH_A4_MM',['../plplotP_8h.html#a1e5f5dadc703e4a5c36491aab7ef692a',1,'plplotP.h']]],
  ['plplot_5fwidth_5fa5_5fmm',['PLPLOT_WIDTH_A5_MM',['../plplotP_8h.html#a9401bef8aac9d41473ed40dbf9878bce',1,'plplotP.h']]],
  ['plplot_5fwxlogdebug',['PLPLOT_wxLogDebug',['../wxPLplot__nanosec_8h.html#ad50cea22083bfe39b785501ed5987392',1,'wxPLplot_nanosec.h']]],
  ['plpoin',['plpoin',['../plplot_8h.html#a391bfdb36f44d04462ff5e486c2eb5c5',1,'plplot.h']]],
  ['plpoin3',['plpoin3',['../plplot_8h.html#a2e8604cbcbccb3f5244cc996515a429d',1,'plplot.h']]],
  ['plpoly3',['plpoly3',['../plplot_8h.html#afa94b6d39d92d9b1d84a46bd936b97ad',1,'plplot.h']]],
  ['plprec',['plprec',['../plplot_8h.html#ad48f6311e95614708d1be02ee03a5aa8',1,'plplot.h']]],
  ['plpsty',['plpsty',['../plplot_8h.html#a270aee0c597b273928187bfe199a991e',1,'plplot.h']]],
  ['plptex',['plptex',['../plplot_8h.html#a318c60235829b3f3f238e6f9e447f9d4',1,'plplot.h']]],
  ['plptex3',['plptex3',['../plplot_8h.html#a3a7796925a5651e0cecface95141f896',1,'plplot.h']]],
  ['plr_5fcmd',['plr_cmd',['../plr_8c.html#a07a997d3daa7f2ba7e6d9447e9f38b32',1,'plr.c']]],
  ['plr_5frd',['plr_rd',['../plr_8c.html#aff85ce4a8e3c83ace2f78fc4eab0045b',1,'plr.c']]],
  ['plr_5frdn',['plr_rdn',['../plr_8c.html#ad15779c5e119c6caa8e6bd162ea3bd13',1,'plr.c']]],
  ['plrandd',['plrandd',['../plplot_8h.html#adb71005b1af64e69fc75a4ebea70de3e',1,'plplot.h']]],
  ['plreplot',['plreplot',['../plplot_8h.html#af1d7cf8090a64f1e8c7567f27c0250fb',1,'plplot.h']]],
  ['plrgbhls',['plrgbhls',['../plplot_8h.html#a32f3be36cc79bd7316d3556d0854a7b8',1,'plplot.h']]],
  ['plschr',['plschr',['../plplot_8h.html#a033d5d483cb260ff6d3b2460f711a81e',1,'plplot.h']]],
  ['plscmap0',['plscmap0',['../plplot_8h.html#aaaa6ee5b8b7f5d382fbf3d3f9abfe504',1,'plplot.h']]],
  ['plscmap0a',['plscmap0a',['../plplot_8h.html#a9eb0eb1c2f850b6df2dc5fa019182ccb',1,'plplot.h']]],
  ['plscmap0n',['plscmap0n',['../plplot_8h.html#a5fad0388a072d5fe94c79a9d966917cc',1,'plplot.h']]],
  ['plscmap1',['plscmap1',['../plplot_8h.html#a7dea99d52e16149018e6044a668b203c',1,'plplot.h']]],
  ['plscmap1_5frange',['plscmap1_range',['../plplot_8h.html#aa7f34554ad31df21ff38f87bfa1b0841',1,'plplot.h']]],
  ['plscmap1a',['plscmap1a',['../plplot_8h.html#aaa8c0c13333601bcb9689b012a94aba0',1,'plplot.h']]],
  ['plscmap1l',['plscmap1l',['../plplot_8h.html#a13c57afe3d60a2c660369903240817f8',1,'plplot.h']]],
  ['plscmap1la',['plscmap1la',['../plplot_8h.html#ab73094a0ea25ef00e069b53cddb818e0',1,'plplot.h']]],
  ['plscmap1n',['plscmap1n',['../plplot_8h.html#a6e9aeabcddf0bdec5551f70f20a4e1d5',1,'plplot.h']]],
  ['plscol0',['plscol0',['../plplot_8h.html#a2ef1d5ab2485dce98975fccc647c2021',1,'plplot.h']]],
  ['plscol0a',['plscol0a',['../plplot_8h.html#ad838886ed16f9c677fa58a644ea73ee5',1,'plplot.h']]],
  ['plscolbg',['plscolbg',['../plplot_8h.html#a264c437f3da38c3b47c047d13758240c',1,'plplot.h']]],
  ['plscolbga',['plscolbga',['../plplot_8h.html#a78902e8b32c44596e9d6c720db261488',1,'plplot.h']]],
  ['plscolor',['plscolor',['../plplot_8h.html#ab837eb4e96d6b0f586c45260afe9e9df',1,'plplot.h']]],
  ['plscompression',['plscompression',['../plplot_8h.html#a94c1ba16a7bc8afa6d7a0ea9f1fb4640',1,'plplot.h']]],
  ['plsdev',['plsdev',['../plplot_8h.html#a77aa8a80f7282107b51afcc7b3447500',1,'plplot.h']]],
  ['plsdidev',['plsdidev',['../plplot_8h.html#ae0a15990db0ea9ff583f95d5cd4e0103',1,'plplot.h']]],
  ['plsdimap',['plsdimap',['../plplot_8h.html#aed24d00600dd572cfbe3cc42192e8fb3',1,'plplot.h']]],
  ['plsdiori',['plsdiori',['../plplot_8h.html#a8ede75c5624fb9d2c58b93a82dc431cf',1,'plplot.h']]],
  ['plsdiplt',['plsdiplt',['../plplot_8h.html#abf3b363eca688f47a73398c970d51a6c',1,'plplot.h']]],
  ['plsdiplz',['plsdiplz',['../plplot_8h.html#a7e474fa3bd1d447273f5954d1e2d34c4',1,'plplot.h']]],
  ['plsdrawmode',['plsdrawmode',['../plplot_8h.html#af8400ecbd64fe9661c0b724b17b5c3ad',1,'plplot.h']]],
  ['plseed',['plseed',['../plplot_8h.html#ad599920c5536f5b558eb4dea7dd700a2',1,'plplot.h']]],
  ['plserv_5fheader',['PLSERV_HEADER',['../metadefs_8h.html#a13e85a1ed167ab43dc64bb8a96c08d54',1,'metadefs.h']]],
  ['plserv_5fversion',['PLSERV_VERSION',['../metadefs_8h.html#ae2a6432d568327d448b7135847092a2b',1,'metadefs.h']]],
  ['plsesc',['plsesc',['../plplot_8h.html#a8861841de6eabf18f8471c21dd655a7d',1,'plplot.h']]],
  ['plsetopt',['plsetopt',['../plplot_8h.html#a899af897dd72e2845334ad1c4ff649da',1,'plplot.h']]],
  ['plsetvar',['plsetvar',['../plplotP_8h.html#a4eeb27aac45f99ad72cc6da3115a587d',1,'plplotP.h']]],
  ['plsfam',['plsfam',['../plplot_8h.html#a0930f605f90b352d19731247825df673',1,'plplot.h']]],
  ['plsfci',['plsfci',['../plplot_8h.html#aededd5e2833d12a61ef5b70ca805fe7f',1,'plplot.h']]],
  ['plsfnam',['plsfnam',['../plplot_8h.html#ae180cc25da7b407dc72577b730b9b9ed',1,'plplot.h']]],
  ['plsfont',['plsfont',['../plplot_8h.html#ad66be92ad40c6e8cdc4de36d6868020f',1,'plplot.h']]],
  ['plshade',['plshade',['../plplot_8h.html#aa864df027d27c705b65e2b1e2170ba0c',1,'plplot.h']]],
  ['plshade1',['plshade1',['../plplot_8h.html#ac3094aae373d21ad461b961593e9482a',1,'plplot.h']]],
  ['plshades',['plshades',['../plplot_8h.html#a939743b6e786099fc3b9e50e5a720c62',1,'plplot.h']]],
  ['plslabelfunc',['plslabelfunc',['../plplot_8h.html#a9374ca78cec47194d25c5b28533ef688',1,'plplot.h']]],
  ['plsmaj',['plsmaj',['../plplot_8h.html#a0a5e4fdc768d2d28d39a283905f84141',1,'plplot.h']]],
  ['plsmem',['plsmem',['../plplot_8h.html#a48210ec0693b84b1b09597a53fa2efdf',1,'plplot.h']]],
  ['plsmema',['plsmema',['../plplot_8h.html#a2da2e157c2bace2d5dd521398f22e144',1,'plplot.h']]],
  ['plsmin',['plsmin',['../plplot_8h.html#a0be47547451e24fbf650e89a8f1308d1',1,'plplot.h']]],
  ['plsori',['plsori',['../plplot_8h.html#a142243bf747c657b25201e741e675089',1,'plplot.h']]],
  ['plspage',['plspage',['../plplot_8h.html#a905adcdc76976608d1f6af6e0ea8b10e',1,'plplot.h']]],
  ['plspal0',['plspal0',['../plplot_8h.html#a578e453aec6f0692a2160ab015ac81aa',1,'plplot.h']]],
  ['plspal1',['plspal1',['../plplot_8h.html#a4f6c2e7087a90e1dda2b194fe66b4065',1,'plplot.h']]],
  ['plspause',['plspause',['../plplot_8h.html#a5333bb0bbf12db5f7303f69b8e4c58ed',1,'plplot.h']]],
  ['plsstrm',['plsstrm',['../plplot_8h.html#ab6578e4880073bcd25fb1d5f7125271d',1,'plplot.h']]],
  ['plssub',['plssub',['../plplot_8h.html#aff7b8a2809bdc37f766ae777a89d5b64',1,'plplot.h']]],
  ['plssym',['plssym',['../plplot_8h.html#ab8057c70946a9e6357c50178c537cd88',1,'plplot.h']]],
  ['plstar',['plstar',['../plplot_8h.html#ae795074b5837df727db082cf49a59c4e',1,'plplot.h']]],
  ['plstart',['plstart',['../plplot_8h.html#af495818ad5ce1a5afb98d50fe5a95aaa',1,'plplot.h']]],
  ['plstate_5fchr',['PLSTATE_CHR',['../plplotP_8h.html#a466c3c0c53d46b141b3c1f4d46bc3456',1,'plplotP.h']]],
  ['plstate_5fcmap0',['PLSTATE_CMAP0',['../plplotP_8h.html#a8d2bf416c54687c37054904f985fb13f',1,'plplotP.h']]],
  ['plstate_5fcmap1',['PLSTATE_CMAP1',['../plplotP_8h.html#ad0a2af1aef551a9ccd4ca00c7fbbd834',1,'plplotP.h']]],
  ['plstate_5fcolor0',['PLSTATE_COLOR0',['../plplotP_8h.html#aea93ee07e6a29ea6fdee6f1362104618',1,'plplotP.h']]],
  ['plstate_5fcolor1',['PLSTATE_COLOR1',['../plplotP_8h.html#aa4d5d7ee225e17548f4066fc4bd27d4e',1,'plplotP.h']]],
  ['plstate_5ffill',['PLSTATE_FILL',['../plplotP_8h.html#a32be3518883413bd04abf4243ee7abda',1,'plplotP.h']]],
  ['plstate_5fsym',['PLSTATE_SYM',['../plplotP_8h.html#a6b3c4f17d069eafddc5971d9988fe5e4',1,'plplotP.h']]],
  ['plstate_5fwidth',['PLSTATE_WIDTH',['../plplotP_8h.html#a6d50332cd83f8d864604ff541655b2be',1,'plplotP.h']]],
  ['plstransform',['plstransform',['../plplot_8h.html#a0e12f03add5dfe781dab30b3817a116c',1,'plplot.h']]],
  ['plstring',['plstring',['../plplot_8h.html#a8c665c48bec2c47ea610d98600453b4d',1,'plplot.h']]],
  ['plstring3',['plstring3',['../plplot_8h.html#a5156dbb2750cd9e45d2de503b9e39d84',1,'plplot.h']]],
  ['plstripa',['plstripa',['../plplot_8h.html#a487121ddd3dee88385c7841b75502cc8',1,'plplot.h']]],
  ['plstripc',['plstripc',['../plplot_8h.html#aab9117fdcdd1327a94f8a32f89be810b',1,'plplot.h']]],
  ['plstripd',['plstripd',['../plplot_8h.html#a3b06951ff31673107f1f88c611b723d9',1,'plplot.h']]],
  ['plstyl',['plstyl',['../plplot_8h.html#ab1a82727605f3794755981ad693b2133',1,'plplot.h']]],
  ['plsurf3d',['plsurf3d',['../plplot_8h.html#a5ccc68e01fcc16286fda4815a7eff4eb',1,'plplot.h']]],
  ['plsurf3dl',['plsurf3dl',['../plplot_8h.html#a5e786eb34f1ad0eae80402a7bb8b92ab',1,'plplot.h']]],
  ['plsvect',['plsvect',['../plplot_8h.html#ab17ca34b9b4dda280c00166a5ed2e8ab',1,'plplot.h']]],
  ['plsvpa',['plsvpa',['../plplot_8h.html#a6403edf5da958ee28512503a868b1f03',1,'plplot.h']]],
  ['plswin_5fdevice',['PLSWIN_DEVICE',['../plplot_8h.html#a8751bd040cbe7a7601a3f3a74d79ba3d',1,'plplot.h']]],
  ['plswin_5fworld',['PLSWIN_WORLD',['../plplot_8h.html#a5c7f09c95ab94bc5c7c06ec219bb5a99',1,'plplot.h']]],
  ['plsxax',['plsxax',['../plplot_8h.html#af49979ee1a133453f970f89772df0daf',1,'plplot.h']]],
  ['plsyax',['plsyax',['../plplot_8h.html#a25ef9eb433e86adbe69ef5458bce1f03',1,'plplot.h']]],
  ['plsym',['plsym',['../plplot_8h.html#aa95f3ab43f2edf1400bd98e434392e37',1,'plplot.h']]],
  ['plszax',['plszax',['../plplot_8h.html#a47e364638c640e4a93f9335bf2a4d803',1,'plplot.h']]],
  ['pltext',['pltext',['../plplot_8h.html#a8b2ab295a0e8d18f34c91722e2748bd6',1,'plplot.h']]],
  ['pltext_5fbackchar',['PLTEXT_BACKCHAR',['../plplot_8h.html#aa6b09e6214ceb51738d8480ac42c3ec2',1,'plplot.h']]],
  ['pltext_5ffontchange',['PLTEXT_FONTCHANGE',['../plplot_8h.html#a8d63b6dbaa221c02421f03349e7a18ea',1,'plplot.h']]],
  ['pltext_5foverline',['PLTEXT_OVERLINE',['../plplot_8h.html#a4042cf40f8c5a41459a50f99b6808832',1,'plplot.h']]],
  ['pltext_5fsubscript',['PLTEXT_SUBSCRIPT',['../plplot_8h.html#a963198b4f7a6e85e2c3136be836a3f88',1,'plplot.h']]],
  ['pltext_5fsuperscript',['PLTEXT_SUPERSCRIPT',['../plplot_8h.html#a22531a3d640ce1c79aab88ec134e1073',1,'plplot.h']]],
  ['pltext_5funderline',['PLTEXT_UNDERLINE',['../plplot_8h.html#af414e60bec2c568dd1f0fe8819865ce7',1,'plplot.h']]],
  ['pltimefmt',['pltimefmt',['../plplot_8h.html#a1cec82073afe1eb3610ac8936d9c2fdc',1,'plplot.h']]],
  ['pltkdisplays',['PLTKDISPLAYS',['../pltkwd_8h.html#a93d9346e8bb931dfcad81011af922f19',1,'pltkwd.h']]],
  ['plvasp',['plvasp',['../plplot_8h.html#a5e8ad8da9112ac06cf73ec865bd2d47d',1,'plplot.h']]],
  ['plvect',['plvect',['../plplot_8h.html#a1e884ebd81d68f044ec60469e5e6e6e9',1,'plplot.h']]],
  ['plvpas',['plvpas',['../plplot_8h.html#a1105d0f36f07fea5fa5b7f1831bc9b8f',1,'plplot.h']]],
  ['plvpor',['plvpor',['../plplot_8h.html#afa8384d804834f433e07b3c78999a984',1,'plplot.h']]],
  ['plvsta',['plvsta',['../plplot_8h.html#ac2bcfdab21636a4f8d60c62c43a3c311',1,'plplot.h']]],
  ['plw3d',['plw3d',['../plplot_8h.html#a6788ee6ca54b0952a8d52f4e5a0ee883',1,'plplot.h']]],
  ['plwidth',['plwidth',['../plplot_8h.html#a599c15e2e2029f6a2506f0eb03659d36',1,'plplot.h']]],
  ['plwind',['plwind',['../plplot_8h.html#ae6cd7548ef5c833e9f97d9176f229d46',1,'plplot.h']]],
  ['plxdisplays',['PLXDISPLAYS',['../plxwd_8h.html#a92c09ce4b5682a1227f46403a9121353',1,'plxwd.h']]],
  ['plxormod',['plxormod',['../plplot_8h.html#a52d7f0be5aab44f2db35c627e9a19688',1,'plplot.h']]],
  ['points_5fper_5finch',['POINTS_PER_INCH',['../svg_8c.html#ae99ebec8aa1d257ed1164f2676994a08',1,'POINTS_PER_INCH():&#160;svg.c'],['../qt_8h.html#ae99ebec8aa1d257ed1164f2676994a08',1,'POINTS_PER_INCH():&#160;qt.h']]],
  ['polyline',['POLYLINE',['../metadefs_8h.html#ae38b6e405395fa5184aaccb260ccb135',1,'metadefs.h']]],
  ['pos',['POS',['../plshade_8c.html#a63cb3834e6075ddad87f8ce324e53988',1,'plshade.c']]],
  ['positive_5fslope',['POSITIVE_SLOPE',['../plshade_8c.html#a370d47b188a024bae0cbdc4fb2708ba8',1,'plshade.c']]],
  ['psx',['PSX',['../ps_8h.html#a81bd405f224a24cc3fd0db79f40507c5',1,'ps.h']]],
  ['psy',['PSY',['../ps_8h.html#a1a0aebfec9c29e451f68a9cca220252f',1,'ps.h']]],
  ['py_5fnotimplemented',['Py_NotImplemented',['../plplotcPYTHON__wrap_8c.html#ae5603e8c5fd8ec50c4936e1012a58cb4',1,'plplotcPYTHON_wrap.c']]],
  ['py_5fssize_5ft_5fmax',['PY_SSIZE_T_MAX',['../plplotcPYTHON__wrap_8c.html#aa5b5990f814eb53730c24c7f911f9132',1,'plplotcPYTHON_wrap.c']]],
  ['py_5fssize_5ft_5fmin',['PY_SSIZE_T_MIN',['../plplotcPYTHON__wrap_8c.html#a9fbcf3e88f34de99fb3bd045cffd6ce4',1,'plplotcPYTHON_wrap.c']]],
  ['py_5ftype',['Py_TYPE',['../plplotcPYTHON__wrap_8c.html#afd489119bf6e3552bdaa6bc365e35e59',1,'plplotcPYTHON_wrap.c']]],
  ['py_5fvisit',['Py_VISIT',['../plplotcPYTHON__wrap_8c.html#a8a5af783da2cdbcfdc7c354f635df8be',1,'plplotcPYTHON_wrap.c']]],
  ['pydescr_5fname',['PyDescr_NAME',['../plplotcPYTHON__wrap_8c.html#a7b007021fc924eb74eccb0bb05d99ad1',1,'plplotcPYTHON_wrap.c']]],
  ['pydescr_5ftype',['PyDescr_TYPE',['../plplotcPYTHON__wrap_8c.html#a0d2bc679367576eb4071b8c3bfe13edc',1,'plplotcPYTHON_wrap.c']]],
  ['pyexc_5fstopiteration',['PyExc_StopIteration',['../plplotcPYTHON__wrap_8c.html#a0cba46b26eb93c57b8b96696ba92adb4',1,'plplotcPYTHON_wrap.c']]],
  ['pyint_5ffromsize_5ft',['PyInt_FromSize_t',['../plplotcPYTHON__wrap_8c.html#a2a72c6061f4d23c35a8340448dd0cd2b',1,'plplotcPYTHON_wrap.c']]],
  ['pyobject_5fdel',['PyObject_Del',['../plplotcPYTHON__wrap_8c.html#a5777895532ba038acdbde39ef6f78a82',1,'PyObject_Del():&#160;plplotcPYTHON_wrap.c'],['../plplotcPYTHON__wrap_8c.html#a3e72f1bb4b2af8f115a750f832d421b4',1,'PyObject_DEL():&#160;plplotcPYTHON_wrap.c']]],
  ['pyobject_5fgenericgetattr',['PyObject_GenericGetAttr',['../plplotcPYTHON__wrap_8c.html#a2d659e3ecdc8d792ec516753e6fd37a2',1,'plplotcPYTHON_wrap.c']]],
  ['pyos_5fsnprintf',['PyOS_snprintf',['../plplotcPYTHON__wrap_8c.html#aaf424b640ab3bb23906652e73030992b',1,'plplotcPYTHON_wrap.c']]],
  ['pysequence_5ffast_5fget_5fitem',['PySequence_Fast_GET_ITEM',['../plplotcPYTHON__wrap_8c.html#ada824e75a50f73e7439516caeaecb478',1,'plplotcPYTHON_wrap.c']]],
  ['pysequence_5fsize',['PySequence_Size',['../plplotcPYTHON__wrap_8c.html#ae0178153199e3020e8d586e0e50fc796',1,'PySequence_Size():&#160;plplotcPYTHON_wrap.c'],['../plplotcPYTHON__wrap_8c.html#ae0178153199e3020e8d586e0e50fc796',1,'PySequence_Size():&#160;plplotcPYTHON_wrap.c']]],
  ['pystring_5fasstringandsize',['PyString_AsStringAndSize',['../plplotcPYTHON__wrap_8c.html#afdc43df5cb9472c0f13c86d8e01aea31',1,'plplotcPYTHON_wrap.c']]]
];
